'''OpenGL extension SGIX.list_priority

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_list_priority'
_DEPRECATED = False
GL_LIST_PRIORITY_SGIX = constant.Constant( 'GL_LIST_PRIORITY_SGIX', 0x8182 )
glGetListParameterfvSGIX = platform.createExtensionFunction( 
'glGetListParameterfvSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLfloatArray,),
doc='glGetListParameterfvSGIX(GLuint(list), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('list','pname','params',),
deprecated=_DEPRECATED,
)

glGetListParameterivSGIX = platform.createExtensionFunction( 
'glGetListParameterivSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetListParameterivSGIX(GLuint(list), GLenum(pname), GLintArray(params)) -> None',
argNames=('list','pname','params',),
deprecated=_DEPRECATED,
)

glListParameterfSGIX = platform.createExtensionFunction( 
'glListParameterfSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLfloat,),
doc='glListParameterfSGIX(GLuint(list), GLenum(pname), GLfloat(param)) -> None',
argNames=('list','pname','param',),
deprecated=_DEPRECATED,
)

glListParameterfvSGIX = platform.createExtensionFunction( 
'glListParameterfvSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLfloatArray,),
doc='glListParameterfvSGIX(GLuint(list), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('list','pname','params',),
deprecated=_DEPRECATED,
)

glListParameteriSGIX = platform.createExtensionFunction( 
'glListParameteriSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,),
doc='glListParameteriSGIX(GLuint(list), GLenum(pname), GLint(param)) -> None',
argNames=('list','pname','param',),
deprecated=_DEPRECATED,
)

glListParameterivSGIX = platform.createExtensionFunction( 
'glListParameterivSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glListParameterivSGIX(GLuint(list), GLenum(pname), GLintArray(params)) -> None',
argNames=('list','pname','params',),
deprecated=_DEPRECATED,
)


def glInitListPrioritySGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.texture_multisample

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_texture_multisample'
_DEPRECATED = False
GL_SAMPLE_POSITION = constant.Constant( 'GL_SAMPLE_POSITION', 0x8E50 )
GL_SAMPLE_MASK = constant.Constant( 'GL_SAMPLE_MASK', 0x8E51 )
GL_SAMPLE_MASK_VALUE = constant.Constant( 'GL_SAMPLE_MASK_VALUE', 0x8E52 )
GL_MAX_SAMPLE_MASK_WORDS = constant.Constant( 'GL_MAX_SAMPLE_MASK_WORDS', 0x8E59 )
glget.addGLGetConstant( GL_MAX_SAMPLE_MASK_WORDS, (1,) )
GL_TEXTURE_2D_MULTISAMPLE = constant.Constant( 'GL_TEXTURE_2D_MULTISAMPLE', 0x9100 )
GL_PROXY_TEXTURE_2D_MULTISAMPLE = constant.Constant( 'GL_PROXY_TEXTURE_2D_MULTISAMPLE', 0x9101 )
GL_TEXTURE_2D_MULTISAMPLE_ARRAY = constant.Constant( 'GL_TEXTURE_2D_MULTISAMPLE_ARRAY', 0x9102 )
GL_PROXY_TEXTURE_2D_MULTISAMPLE_ARRAY = constant.Constant( 'GL_PROXY_TEXTURE_2D_MULTISAMPLE_ARRAY', 0x9103 )
GL_TEXTURE_BINDING_2D_MULTISAMPLE = constant.Constant( 'GL_TEXTURE_BINDING_2D_MULTISAMPLE', 0x9104 )
glget.addGLGetConstant( GL_TEXTURE_BINDING_2D_MULTISAMPLE, (1,) )
GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY = constant.Constant( 'GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY', 0x9105 )
glget.addGLGetConstant( GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY, (1,) )
GL_TEXTURE_SAMPLES = constant.Constant( 'GL_TEXTURE_SAMPLES', 0x9106 )
GL_TEXTURE_FIXED_SAMPLE_LOCATIONS = constant.Constant( 'GL_TEXTURE_FIXED_SAMPLE_LOCATIONS', 0x9107 )
GL_SAMPLER_2D_MULTISAMPLE = constant.Constant( 'GL_SAMPLER_2D_MULTISAMPLE', 0x9108 )
GL_INT_SAMPLER_2D_MULTISAMPLE = constant.Constant( 'GL_INT_SAMPLER_2D_MULTISAMPLE', 0x9109 )
GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE', 0x910A )
GL_SAMPLER_2D_MULTISAMPLE_ARRAY = constant.Constant( 'GL_SAMPLER_2D_MULTISAMPLE_ARRAY', 0x910B )
GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY = constant.Constant( 'GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY', 0x910C )
GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY', 0x910D )
GL_MAX_COLOR_TEXTURE_SAMPLES = constant.Constant( 'GL_MAX_COLOR_TEXTURE_SAMPLES', 0x910E )
glget.addGLGetConstant( GL_MAX_COLOR_TEXTURE_SAMPLES, (1,) )
GL_MAX_DEPTH_TEXTURE_SAMPLES = constant.Constant( 'GL_MAX_DEPTH_TEXTURE_SAMPLES', 0x910F )
glget.addGLGetConstant( GL_MAX_DEPTH_TEXTURE_SAMPLES, (1,) )
GL_MAX_INTEGER_SAMPLES = constant.Constant( 'GL_MAX_INTEGER_SAMPLES', 0x9110 )
glget.addGLGetConstant( GL_MAX_INTEGER_SAMPLES, (1,) )
glTexImage2DMultisample = platform.createExtensionFunction( 
'glTexImage2DMultisample',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLboolean,),
doc='glTexImage2DMultisample(GLenum(target), GLsizei(samples), GLint(internalformat), GLsizei(width), GLsizei(height), GLboolean(fixedsamplelocations)) -> None',
argNames=('target','samples','internalformat','width','height','fixedsamplelocations',),
deprecated=_DEPRECATED,
)

glTexImage3DMultisample = platform.createExtensionFunction( 
'glTexImage3DMultisample',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLboolean,),
doc='glTexImage3DMultisample(GLenum(target), GLsizei(samples), GLint(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLboolean(fixedsamplelocations)) -> None',
argNames=('target','samples','internalformat','width','height','depth','fixedsamplelocations',),
deprecated=_DEPRECATED,
)

glGetMultisamplefv = platform.createExtensionFunction( 
'glGetMultisamplefv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLfloatArray,),
doc='glGetMultisamplefv(GLenum(pname), GLuint(index), GLfloatArray(val)) -> None',
argNames=('pname','index','val',),
deprecated=_DEPRECATED,
)

glSampleMaski = platform.createExtensionFunction( 
'glSampleMaski',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLbitfield,),
doc='glSampleMaski(GLuint(index), GLbitfield(mask)) -> None',
argNames=('index','mask',),
deprecated=_DEPRECATED,
)


def glInitTextureMultisampleARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.async_histogram

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.async_histogram to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces a new asynchronous mode for histogram
	and minmax readbacks.  It allows programs to get the contents of a
	histogram or minmax table without blocking and to continue issuing
	graphics commands during the readback.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/async_histogram.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.SGIX.async_histogram import *
### END AUTOGENERATED SECTION


'''OpenGL extension ATI.fragment_shader

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_fragment_shader'
_DEPRECATED = False
GL_FRAGMENT_SHADER_ATI = constant.Constant( 'GL_FRAGMENT_SHADER_ATI', 0x8920 )
glget.addGLGetConstant( GL_FRAGMENT_SHADER_ATI, (1,) )
GL_REG_0_ATI = constant.Constant( 'GL_REG_0_ATI', 0x8921 )
GL_REG_1_ATI = constant.Constant( 'GL_REG_1_ATI', 0x8922 )
GL_REG_2_ATI = constant.Constant( 'GL_REG_2_ATI', 0x8923 )
GL_REG_3_ATI = constant.Constant( 'GL_REG_3_ATI', 0x8924 )
GL_REG_4_ATI = constant.Constant( 'GL_REG_4_ATI', 0x8925 )
GL_REG_5_ATI = constant.Constant( 'GL_REG_5_ATI', 0x8926 )
GL_REG_6_ATI = constant.Constant( 'GL_REG_6_ATI', 0x8927 )
GL_REG_7_ATI = constant.Constant( 'GL_REG_7_ATI', 0x8928 )
GL_REG_8_ATI = constant.Constant( 'GL_REG_8_ATI', 0x8929 )
GL_REG_9_ATI = constant.Constant( 'GL_REG_9_ATI', 0x892A )
GL_REG_10_ATI = constant.Constant( 'GL_REG_10_ATI', 0x892B )
GL_REG_11_ATI = constant.Constant( 'GL_REG_11_ATI', 0x892C )
GL_REG_12_ATI = constant.Constant( 'GL_REG_12_ATI', 0x892D )
GL_REG_13_ATI = constant.Constant( 'GL_REG_13_ATI', 0x892E )
GL_REG_14_ATI = constant.Constant( 'GL_REG_14_ATI', 0x892F )
GL_REG_15_ATI = constant.Constant( 'GL_REG_15_ATI', 0x8930 )
GL_REG_16_ATI = constant.Constant( 'GL_REG_16_ATI', 0x8931 )
GL_REG_17_ATI = constant.Constant( 'GL_REG_17_ATI', 0x8932 )
GL_REG_18_ATI = constant.Constant( 'GL_REG_18_ATI', 0x8933 )
GL_REG_19_ATI = constant.Constant( 'GL_REG_19_ATI', 0x8934 )
GL_REG_20_ATI = constant.Constant( 'GL_REG_20_ATI', 0x8935 )
GL_REG_21_ATI = constant.Constant( 'GL_REG_21_ATI', 0x8936 )
GL_REG_22_ATI = constant.Constant( 'GL_REG_22_ATI', 0x8937 )
GL_REG_23_ATI = constant.Constant( 'GL_REG_23_ATI', 0x8938 )
GL_REG_24_ATI = constant.Constant( 'GL_REG_24_ATI', 0x8939 )
GL_REG_25_ATI = constant.Constant( 'GL_REG_25_ATI', 0x893A )
GL_REG_26_ATI = constant.Constant( 'GL_REG_26_ATI', 0x893B )
GL_REG_27_ATI = constant.Constant( 'GL_REG_27_ATI', 0x893C )
GL_REG_28_ATI = constant.Constant( 'GL_REG_28_ATI', 0x893D )
GL_REG_29_ATI = constant.Constant( 'GL_REG_29_ATI', 0x893E )
GL_REG_30_ATI = constant.Constant( 'GL_REG_30_ATI', 0x893F )
GL_REG_31_ATI = constant.Constant( 'GL_REG_31_ATI', 0x8940 )
GL_CON_0_ATI = constant.Constant( 'GL_CON_0_ATI', 0x8941 )
GL_CON_1_ATI = constant.Constant( 'GL_CON_1_ATI', 0x8942 )
GL_CON_2_ATI = constant.Constant( 'GL_CON_2_ATI', 0x8943 )
GL_CON_3_ATI = constant.Constant( 'GL_CON_3_ATI', 0x8944 )
GL_CON_4_ATI = constant.Constant( 'GL_CON_4_ATI', 0x8945 )
GL_CON_5_ATI = constant.Constant( 'GL_CON_5_ATI', 0x8946 )
GL_CON_6_ATI = constant.Constant( 'GL_CON_6_ATI', 0x8947 )
GL_CON_7_ATI = constant.Constant( 'GL_CON_7_ATI', 0x8948 )
GL_CON_8_ATI = constant.Constant( 'GL_CON_8_ATI', 0x8949 )
GL_CON_9_ATI = constant.Constant( 'GL_CON_9_ATI', 0x894A )
GL_CON_10_ATI = constant.Constant( 'GL_CON_10_ATI', 0x894B )
GL_CON_11_ATI = constant.Constant( 'GL_CON_11_ATI', 0x894C )
GL_CON_12_ATI = constant.Constant( 'GL_CON_12_ATI', 0x894D )
GL_CON_13_ATI = constant.Constant( 'GL_CON_13_ATI', 0x894E )
GL_CON_14_ATI = constant.Constant( 'GL_CON_14_ATI', 0x894F )
GL_CON_15_ATI = constant.Constant( 'GL_CON_15_ATI', 0x8950 )
GL_CON_16_ATI = constant.Constant( 'GL_CON_16_ATI', 0x8951 )
GL_CON_17_ATI = constant.Constant( 'GL_CON_17_ATI', 0x8952 )
GL_CON_18_ATI = constant.Constant( 'GL_CON_18_ATI', 0x8953 )
GL_CON_19_ATI = constant.Constant( 'GL_CON_19_ATI', 0x8954 )
GL_CON_20_ATI = constant.Constant( 'GL_CON_20_ATI', 0x8955 )
GL_CON_21_ATI = constant.Constant( 'GL_CON_21_ATI', 0x8956 )
GL_CON_22_ATI = constant.Constant( 'GL_CON_22_ATI', 0x8957 )
GL_CON_23_ATI = constant.Constant( 'GL_CON_23_ATI', 0x8958 )
GL_CON_24_ATI = constant.Constant( 'GL_CON_24_ATI', 0x8959 )
GL_CON_25_ATI = constant.Constant( 'GL_CON_25_ATI', 0x895A )
GL_CON_26_ATI = constant.Constant( 'GL_CON_26_ATI', 0x895B )
GL_CON_27_ATI = constant.Constant( 'GL_CON_27_ATI', 0x895C )
GL_CON_28_ATI = constant.Constant( 'GL_CON_28_ATI', 0x895D )
GL_CON_29_ATI = constant.Constant( 'GL_CON_29_ATI', 0x895E )
GL_CON_30_ATI = constant.Constant( 'GL_CON_30_ATI', 0x895F )
GL_CON_31_ATI = constant.Constant( 'GL_CON_31_ATI', 0x8960 )
GL_MOV_ATI = constant.Constant( 'GL_MOV_ATI', 0x8961 )
GL_ADD_ATI = constant.Constant( 'GL_ADD_ATI', 0x8963 )
GL_MUL_ATI = constant.Constant( 'GL_MUL_ATI', 0x8964 )
GL_SUB_ATI = constant.Constant( 'GL_SUB_ATI', 0x8965 )
GL_DOT3_ATI = constant.Constant( 'GL_DOT3_ATI', 0x8966 )
GL_DOT4_ATI = constant.Constant( 'GL_DOT4_ATI', 0x8967 )
GL_MAD_ATI = constant.Constant( 'GL_MAD_ATI', 0x8968 )
GL_LERP_ATI = constant.Constant( 'GL_LERP_ATI', 0x8969 )
GL_CND_ATI = constant.Constant( 'GL_CND_ATI', 0x896A )
GL_CND0_ATI = constant.Constant( 'GL_CND0_ATI', 0x896B )
GL_DOT2_ADD_ATI = constant.Constant( 'GL_DOT2_ADD_ATI', 0x896C )
GL_SECONDARY_INTERPOLATOR_ATI = constant.Constant( 'GL_SECONDARY_INTERPOLATOR_ATI', 0x896D )
GL_NUM_FRAGMENT_REGISTERS_ATI = constant.Constant( 'GL_NUM_FRAGMENT_REGISTERS_ATI', 0x896E )
GL_NUM_FRAGMENT_CONSTANTS_ATI = constant.Constant( 'GL_NUM_FRAGMENT_CONSTANTS_ATI', 0x896F )
GL_NUM_PASSES_ATI = constant.Constant( 'GL_NUM_PASSES_ATI', 0x8970 )
GL_NUM_INSTRUCTIONS_PER_PASS_ATI = constant.Constant( 'GL_NUM_INSTRUCTIONS_PER_PASS_ATI', 0x8971 )
GL_NUM_INSTRUCTIONS_TOTAL_ATI = constant.Constant( 'GL_NUM_INSTRUCTIONS_TOTAL_ATI', 0x8972 )
GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI = constant.Constant( 'GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI', 0x8973 )
GL_NUM_LOOPBACK_COMPONENTS_ATI = constant.Constant( 'GL_NUM_LOOPBACK_COMPONENTS_ATI', 0x8974 )
GL_COLOR_ALPHA_PAIRING_ATI = constant.Constant( 'GL_COLOR_ALPHA_PAIRING_ATI', 0x8975 )
GL_SWIZZLE_STR_ATI = constant.Constant( 'GL_SWIZZLE_STR_ATI', 0x8976 )
GL_SWIZZLE_STQ_ATI = constant.Constant( 'GL_SWIZZLE_STQ_ATI', 0x8977 )
GL_SWIZZLE_STR_DR_ATI = constant.Constant( 'GL_SWIZZLE_STR_DR_ATI', 0x8978 )
GL_SWIZZLE_STQ_DQ_ATI = constant.Constant( 'GL_SWIZZLE_STQ_DQ_ATI', 0x8979 )
GL_SWIZZLE_STRQ_ATI = constant.Constant( 'GL_SWIZZLE_STRQ_ATI', 0x897A )
GL_SWIZZLE_STRQ_DQ_ATI = constant.Constant( 'GL_SWIZZLE_STRQ_DQ_ATI', 0x897B )
GL_RED_BIT_ATI = constant.Constant( 'GL_RED_BIT_ATI', 0x1 )
GL_GREEN_BIT_ATI = constant.Constant( 'GL_GREEN_BIT_ATI', 0x2 )
GL_BLUE_BIT_ATI = constant.Constant( 'GL_BLUE_BIT_ATI', 0x4 )
GL_2X_BIT_ATI = constant.Constant( 'GL_2X_BIT_ATI', 0x1 )
GL_4X_BIT_ATI = constant.Constant( 'GL_4X_BIT_ATI', 0x2 )
GL_8X_BIT_ATI = constant.Constant( 'GL_8X_BIT_ATI', 0x4 )
GL_HALF_BIT_ATI = constant.Constant( 'GL_HALF_BIT_ATI', 0x8 )
GL_QUARTER_BIT_ATI = constant.Constant( 'GL_QUARTER_BIT_ATI', 0x10 )
GL_EIGHTH_BIT_ATI = constant.Constant( 'GL_EIGHTH_BIT_ATI', 0x20 )
GL_SATURATE_BIT_ATI = constant.Constant( 'GL_SATURATE_BIT_ATI', 0x40 )
GL_COMP_BIT_ATI = constant.Constant( 'GL_COMP_BIT_ATI', 0x2 )
GL_NEGATE_BIT_ATI = constant.Constant( 'GL_NEGATE_BIT_ATI', 0x4 )
GL_BIAS_BIT_ATI = constant.Constant( 'GL_BIAS_BIT_ATI', 0x8 )
glGenFragmentShadersATI = platform.createExtensionFunction( 
'glGenFragmentShadersATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLuint, 
argTypes=(constants.GLuint,),
doc='glGenFragmentShadersATI(GLuint(range)) -> constants.GLuint',
argNames=('range',),
deprecated=_DEPRECATED,
)

glBindFragmentShaderATI = platform.createExtensionFunction( 
'glBindFragmentShaderATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glBindFragmentShaderATI(GLuint(id)) -> None',
argNames=('id',),
deprecated=_DEPRECATED,
)

glDeleteFragmentShaderATI = platform.createExtensionFunction( 
'glDeleteFragmentShaderATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glDeleteFragmentShaderATI(GLuint(id)) -> None',
argNames=('id',),
deprecated=_DEPRECATED,
)

glBeginFragmentShaderATI = platform.createExtensionFunction( 
'glBeginFragmentShaderATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glBeginFragmentShaderATI() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glEndFragmentShaderATI = platform.createExtensionFunction( 
'glEndFragmentShaderATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glEndFragmentShaderATI() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glPassTexCoordATI = platform.createExtensionFunction( 
'glPassTexCoordATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,),
doc='glPassTexCoordATI(GLuint(dst), GLuint(coord), GLenum(swizzle)) -> None',
argNames=('dst','coord','swizzle',),
deprecated=_DEPRECATED,
)

glSampleMapATI = platform.createExtensionFunction( 
'glSampleMapATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,),
doc='glSampleMapATI(GLuint(dst), GLuint(interp), GLenum(swizzle)) -> None',
argNames=('dst','interp','swizzle',),
deprecated=_DEPRECATED,
)

glColorFragmentOp1ATI = platform.createExtensionFunction( 
'glColorFragmentOp1ATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glColorFragmentOp1ATI(GLenum(op), GLuint(dst), GLuint(dstMask), GLuint(dstMod), GLuint(arg1), GLuint(arg1Rep), GLuint(arg1Mod)) -> None',
argNames=('op','dst','dstMask','dstMod','arg1','arg1Rep','arg1Mod',),
deprecated=_DEPRECATED,
)

glColorFragmentOp2ATI = platform.createExtensionFunction( 
'glColorFragmentOp2ATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glColorFragmentOp2ATI(GLenum(op), GLuint(dst), GLuint(dstMask), GLuint(dstMod), GLuint(arg1), GLuint(arg1Rep), GLuint(arg1Mod), GLuint(arg2), GLuint(arg2Rep), GLuint(arg2Mod)) -> None',
argNames=('op','dst','dstMask','dstMod','arg1','arg1Rep','arg1Mod','arg2','arg2Rep','arg2Mod',),
deprecated=_DEPRECATED,
)

glColorFragmentOp3ATI = platform.createExtensionFunction( 
'glColorFragmentOp3ATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glColorFragmentOp3ATI(GLenum(op), GLuint(dst), GLuint(dstMask), GLuint(dstMod), GLuint(arg1), GLuint(arg1Rep), GLuint(arg1Mod), GLuint(arg2), GLuint(arg2Rep), GLuint(arg2Mod), GLuint(arg3), GLuint(arg3Rep), GLuint(arg3Mod)) -> None',
argNames=('op','dst','dstMask','dstMod','arg1','arg1Rep','arg1Mod','arg2','arg2Rep','arg2Mod','arg3','arg3Rep','arg3Mod',),
deprecated=_DEPRECATED,
)

glAlphaFragmentOp1ATI = platform.createExtensionFunction( 
'glAlphaFragmentOp1ATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glAlphaFragmentOp1ATI(GLenum(op), GLuint(dst), GLuint(dstMod), GLuint(arg1), GLuint(arg1Rep), GLuint(arg1Mod)) -> None',
argNames=('op','dst','dstMod','arg1','arg1Rep','arg1Mod',),
deprecated=_DEPRECATED,
)

glAlphaFragmentOp2ATI = platform.createExtensionFunction( 
'glAlphaFragmentOp2ATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glAlphaFragmentOp2ATI(GLenum(op), GLuint(dst), GLuint(dstMod), GLuint(arg1), GLuint(arg1Rep), GLuint(arg1Mod), GLuint(arg2), GLuint(arg2Rep), GLuint(arg2Mod)) -> None',
argNames=('op','dst','dstMod','arg1','arg1Rep','arg1Mod','arg2','arg2Rep','arg2Mod',),
deprecated=_DEPRECATED,
)

glAlphaFragmentOp3ATI = platform.createExtensionFunction( 
'glAlphaFragmentOp3ATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glAlphaFragmentOp3ATI(GLenum(op), GLuint(dst), GLuint(dstMod), GLuint(arg1), GLuint(arg1Rep), GLuint(arg1Mod), GLuint(arg2), GLuint(arg2Rep), GLuint(arg2Mod), GLuint(arg3), GLuint(arg3Rep), GLuint(arg3Mod)) -> None',
argNames=('op','dst','dstMod','arg1','arg1Rep','arg1Mod','arg2','arg2Rep','arg2Mod','arg3','arg3Rep','arg3Mod',),
deprecated=_DEPRECATED,
)

glSetFragmentShaderConstantATI = platform.createExtensionFunction( 
'glSetFragmentShaderConstantATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLfloatArray,),
doc='glSetFragmentShaderConstantATI(GLuint(dst), GLfloatArray(value)) -> None',
argNames=('dst','value',),
deprecated=_DEPRECATED,
)


def glInitFragmentShaderATI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ATI.text_fragment_shader

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_text_fragment_shader'
_DEPRECATED = False
GL_TEXT_FRAGMENT_SHADER_ATI = constant.Constant( 'GL_TEXT_FRAGMENT_SHADER_ATI', 0x8200 )
glget.addGLGetConstant( GL_TEXT_FRAGMENT_SHADER_ATI, (1,) )


def glInitTextFragmentShaderATI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension GREMEDY.string_marker

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_GREMEDY_string_marker'
_DEPRECATED = False

glStringMarkerGREMEDY = platform.createExtensionFunction( 
'glStringMarkerGREMEDY',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,ctypes.c_void_p,),
doc='glStringMarkerGREMEDY(GLsizei(len), c_void_p(string)) -> None',
argNames=('len','string',),
deprecated=_DEPRECATED,
)


def glInitStringMarkerGREMEDY():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.color_subtable

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_color_subtable'
_DEPRECATED = False

glColorSubTableEXT = platform.createExtensionFunction( 
'glColorSubTableEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glColorSubTableEXT(GLenum(target), GLsizei(start), GLsizei(count), GLenum(format), GLenum(type), c_void_p(data)) -> None',
argNames=('target','start','count','format','type','data',),
deprecated=_DEPRECATED,
)

glCopyColorSubTableEXT = platform.createExtensionFunction( 
'glCopyColorSubTableEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,constants.GLint,constants.GLint,constants.GLsizei,),
doc='glCopyColorSubTableEXT(GLenum(target), GLsizei(start), GLint(x), GLint(y), GLsizei(width)) -> None',
argNames=('target','start','x','y','width',),
deprecated=_DEPRECATED,
)


def glInitColorSubtableEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension INTEL.parallel_arrays

This module customises the behaviour of the 
OpenGL.raw.GL.INTEL.parallel_arrays to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds the ability to format vertex arrays in a way that's 

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/INTEL/parallel_arrays.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.INTEL.parallel_arrays import *
### END AUTOGENERATED SECTION


'''OpenGL extension NV.vertex_array_range2

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_vertex_array_range2'
_DEPRECATED = False
GL_VERTEX_ARRAY_RANGE_WITHOUT_FLUSH_NV = constant.Constant( 'GL_VERTEX_ARRAY_RANGE_WITHOUT_FLUSH_NV', 0x8533 )


def glInitVertexArrayRange2NV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.vertex_array_object

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_vertex_array_object'
_DEPRECATED = False
GL_VERTEX_ARRAY_BINDING = constant.Constant( 'GL_VERTEX_ARRAY_BINDING', 0x85B5 )
glget.addGLGetConstant( GL_VERTEX_ARRAY_BINDING, (1,) )
glBindVertexArray = platform.createExtensionFunction( 
'glBindVertexArray',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glBindVertexArray(GLuint(array)) -> None',
argNames=('array',),
deprecated=_DEPRECATED,
)

glDeleteVertexArrays = platform.createExtensionFunction( 
'glDeleteVertexArrays',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDeleteVertexArrays(GLsizei(n), GLuintArray(arrays)) -> None',
argNames=('n','arrays',),
deprecated=_DEPRECATED,
)

glGenVertexArrays = platform.createExtensionFunction( 
'glGenVertexArrays',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glGenVertexArrays(GLsizei(n), GLuintArray(arrays)) -> None',
argNames=('n','arrays',),
deprecated=_DEPRECATED,
)

glIsVertexArray = platform.createExtensionFunction( 
'glIsVertexArray',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsVertexArray(GLuint(array)) -> constants.GLboolean',
argNames=('array',),
deprecated=_DEPRECATED,
)


def glInitVertexArrayObjectARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.geometry_shader4

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_geometry_shader4'
_DEPRECATED = False
GL_GEOMETRY_SHADER_EXT = constant.Constant( 'GL_GEOMETRY_SHADER_EXT', 0x8DD9 )
GL_MAX_GEOMETRY_VARYING_COMPONENTS_EXT = constant.Constant( 'GL_MAX_GEOMETRY_VARYING_COMPONENTS_EXT', 0x8DDD )
glget.addGLGetConstant( GL_MAX_GEOMETRY_VARYING_COMPONENTS_EXT, (1,) )
GL_MAX_VERTEX_VARYING_COMPONENTS_EXT = constant.Constant( 'GL_MAX_VERTEX_VARYING_COMPONENTS_EXT', 0x8DDE )
glget.addGLGetConstant( GL_MAX_VERTEX_VARYING_COMPONENTS_EXT, (1,) )
GL_MAX_VARYING_COMPONENTS_EXT = constant.Constant( 'GL_MAX_VARYING_COMPONENTS_EXT', 0x8B4B )
glget.addGLGetConstant( GL_MAX_VARYING_COMPONENTS_EXT, (1,) )
GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_EXT = constant.Constant( 'GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_EXT', 0x8DDF )
glget.addGLGetConstant( GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_EXT, (1,) )
GL_MAX_GEOMETRY_OUTPUT_VERTICES_EXT = constant.Constant( 'GL_MAX_GEOMETRY_OUTPUT_VERTICES_EXT', 0x8DE0 )
glget.addGLGetConstant( GL_MAX_GEOMETRY_OUTPUT_VERTICES_EXT, (1,) )
GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_EXT = constant.Constant( 'GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_EXT', 0x8DE1 )
glget.addGLGetConstant( GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_EXT, (1,) )
glProgramParameteriEXT = platform.createExtensionFunction( 
'glProgramParameteriEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLint,),
doc='glProgramParameteriEXT(GLuint(program), GLenum(pname), GLint(value)) -> None',
argNames=('program','pname','value',),
deprecated=_DEPRECATED,
)


def glInitGeometryShader4EXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.pixel_data_range

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_pixel_data_range'
_DEPRECATED = False
GL_WRITE_PIXEL_DATA_RANGE_NV = constant.Constant( 'GL_WRITE_PIXEL_DATA_RANGE_NV', 0x8878 )
GL_READ_PIXEL_DATA_RANGE_NV = constant.Constant( 'GL_READ_PIXEL_DATA_RANGE_NV', 0x8879 )
GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV = constant.Constant( 'GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV', 0x887A )
glget.addGLGetConstant( GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV, (1,) )
GL_READ_PIXEL_DATA_RANGE_LENGTH_NV = constant.Constant( 'GL_READ_PIXEL_DATA_RANGE_LENGTH_NV', 0x887B )
glget.addGLGetConstant( GL_READ_PIXEL_DATA_RANGE_LENGTH_NV, (1,) )
GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV = constant.Constant( 'GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV', 0x887C )
GL_READ_PIXEL_DATA_RANGE_POINTER_NV = constant.Constant( 'GL_READ_PIXEL_DATA_RANGE_POINTER_NV', 0x887D )
glPixelDataRangeNV = platform.createExtensionFunction( 
'glPixelDataRangeNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glPixelDataRangeNV(GLenum(target), GLsizei(length), c_void_p(pointer)) -> None',
argNames=('target','length','pointer',),
deprecated=_DEPRECATED,
)

glFlushPixelDataRangeNV = platform.createExtensionFunction( 
'glFlushPixelDataRangeNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glFlushPixelDataRangeNV(GLenum(target)) -> None',
argNames=('target',),
deprecated=_DEPRECATED,
)


def glInitPixelDataRangeNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



#! /usr/bin/env python
import unittest, pygame, pygame.display, time, traceback, os, sys
import logging 
logging.basicConfig()

try:
    from numpy import *
except ImportError, err:
    try:
        from Numeric import *
    except ImportError, err:
        array = None

pygame.display.init()
import OpenGL 
OpenGL.CONTEXT_CHECKING = True
OpenGL.FORWARD_COMPATIBLE_ONLY = True
from OpenGL.GL import *
try:
    glGetError()
except error.NoContext, err:
    # good, should have got this error 
    pass
else:
    raise RuntimeError( """Did not catch invalid context!""" )
from OpenGL import constants, error
from OpenGL.GLU import *
from OpenGL.arrays import arraydatatype
import OpenGL
from OpenGL.extensions import alternate
import ctypes
from OpenGL.GL.framebufferobjects import *
from OpenGL.GL.EXT.multi_draw_arrays import *
from OpenGL.GL.ARB.imaging import *

glMultiDrawElements = alternate( 
    glMultiDrawElementsEXT, glMultiDrawElements, 
)


class Tests( unittest.TestCase ):
    evaluator_ctrlpoints = [[[ -1.5, -1.5, 4.0], [-0.5, -1.5, 2.0], [0.5, -1.5,
        -1.0], [1.5, -1.5, 2.0]], [[-1.5, -0.5, 1.0], [-0.5, -0.5, 3.0], [0.5, -0.5,
        0.0], [1.5, -0.5, -1.0]], [[-1.5, 0.5, 4.0], [-0.5, 0.5, 0.0], [0.5, 0.5,
        3.0], [1.5, 0.5, 4.0]], [[-1.5, 1.5, -2.0], [-0.5, 1.5, -2.0], [0.5, 1.5,
        0.0], [1.5, 1.5, -1.0]]]
    width = height = 300
    def setUp( self ):
        """Set up the operation"""
        
        self.screen = pygame.display.set_mode(
            (self.width,self.height),
            pygame.OPENGL | pygame.DOUBLEBUF,
        )
        
        pygame.display.set_caption('Testing system')
        pygame.key.set_repeat(500,30)
        glMatrixMode (GL_PROJECTION)
        glLoadIdentity()
        gluPerspective(40.0, 300/300, 1.0, 20.0)
        glMatrixMode(GL_MODELVIEW)
        glLoadIdentity()
        gluLookAt(
            -2,0,3, # eyepoint
            0,0,0, # center-of-view
            0,1,0, # up-vector
        )
        glClearColor( 0,0,.25, 0 )
        glClear( GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT )
    
    def tearDown( self ):
        glFlush()
        pygame.display.flip()
        time.sleep( .25 )
        #raw_input( 'Okay? ' )
    def test_arrayPointer( self ):
        dt = arraydatatype.GLuintArray
        d = dt.zeros( (3,))
        dp = dt.typedPointer( d )
        assert dp[0] == 0 
        assert dp[1] == 0
        assert dp[2] == 0
        dp[1] = 1
        assert dp[1] == 1
        assert d[1] == 1
    def test_ctypes_array( self ):
        color = (GLfloat * 3)( 0,1,0 )
        glColor3fv( color )
    if (not OpenGL.ERROR_ON_COPY) or array:	
        def test_evaluator( self ):
            """Test whether the evaluator functions work"""
            glDisable(GL_CULL_FACE)
            glEnable(GL_MAP2_VERTEX_3)
            glEnable(GL_DEPTH_TEST)
            glEnable(GL_NORMALIZE)
            if array:
                ctrl_points = array( self.evaluator_ctrlpoints,'f')
            else:
                ctrl_points = self.evaluator_ctrlpoints
            glMap2f(GL_MAP2_VERTEX_3, 0, 1, 0, 1, ctrl_points)
            glMapGrid2f(20, 0.0, 1.0, 20, 0.0, 1.0)
            glShadeModel(GL_FLAT)
            glEvalMesh2(GL_FILL, 0, 20, 0, 20)
            glTranslatef( 0,0.001, 0 )
            glEvalMesh2(GL_POINT, 0, 20, 0, 20)
    def test_nurbs_raw( self ):
        """Test nurbs rendering using raw API calls"""
        from OpenGL.raw import GLU 
        knots = (constants.GLfloat* 8) ( 0,0,0,0,1,1,1,1 )
        ctlpoints = (constants.GLfloat*(3*4*4))( -3., -3., -3.,
            -3., -1., -3.,
            -3.,  1., -3.,
            -3.,  3., -3.,

        -1., -3., -3.,
            -1., -1.,  3.,
            -1.,  1.,  3.,
            -1.,  3., -3.,

        1., -3., -3.,
             1., -1.,  3.,
             1.,  1.,  3.,
             1.,  3., -3.,

        3., -3., -3.,
            3., -1., -3.,
             3.,  1., -3.,
             3.,  3., -3. )
        theNurb = gluNewNurbsRenderer()
        GLU.gluBeginSurface(theNurb)
        GLU.gluNurbsSurface(
            theNurb, 
            8, ctypes.byref(knots), 8, ctypes.byref(knots),
            4 * 3, 3, ctypes.byref( ctlpoints ),
            4, 4, GL_MAP2_VERTEX_3
        )
        GLU.gluEndSurface(theNurb)
    if array:
        def test_nurbs_raw_arrays( self ):
            """Test nurbs rendering using raw API calls with arrays"""
            from OpenGL.raw import GLU 
            import numpy
            knots = numpy.array( ( 0,0,0,0,1,1,1,1 ), 'f' )
            ctlpoints = numpy.array( [[[-3., -3., -3.],
                [-3., -1., -3.],
                [-3.,  1., -3.],
                [-3.,  3., -3.]],

            [[-1., -3., -3.],
                [-1., -1.,  3.],
                [-1.,  1.,  3.],
                [-1.,  3., -3.]],

            [[ 1., -3., -3.],
                [ 1., -1.,  3.],
                [ 1.,  1.,  3.],
                [ 1.,  3., -3.]],

            [[ 3., -3., -3.],
                [ 3., -1., -3.],
                [ 3.,  1., -3.],
                [ 3.,  3., -3.]]], 'f' )
            theNurb = GLU.gluNewNurbsRenderer()
            GLU.gluBeginSurface(theNurb)
            GLU.gluNurbsSurface(
                theNurb, 
                8, knots, 8, knots,
                4 * 3, 3, ctlpoints ,
                4, 4, GL_MAP2_VERTEX_3
            )
            GLU.gluEndSurface(theNurb)
        def test_nurbs( self ):
            """Test nurbs rendering"""
            from OpenGL.raw import GLU 
            def buildControlPoints( ):
                ctlpoints = zeros( (4,4,3), 'd')
                for u in range( 4 ):
                    for v in range( 4):
                        ctlpoints[u][v][0] = 2.0*(u - 1.5)
                        ctlpoints[u][v][1] = 2.0*(v - 1.5);
                        if (u == 1 or u ==2) and (v == 1 or v == 2):
                            ctlpoints[u][v][2] = 3.0;
                        else:
                            ctlpoints[u][v][2] = -3.0;
                return ctlpoints
            controlPoints = buildControlPoints()
            theNurb = GLU.gluNewNurbsRenderer()[0]
            #theNurb = gluNewNurbsRenderer();
            gluNurbsProperty(theNurb, GLU_SAMPLING_TOLERANCE, 25.0);
            gluNurbsProperty(theNurb, GLU_DISPLAY_MODE, GLU_FILL);
            knots= array ([0.0, 0.0, 0.0, 0.0, 1.0, 1.0, 1.0, 1.0], "d")
            glPushMatrix();
            try:
                glRotatef(330.0, 1.,0.,0.);
                glScalef (0.5, 0.5, 0.5);

                gluBeginSurface(theNurb);
                try:
                    gluNurbsSurface(
                        theNurb,
                        knots, knots,
                        controlPoints,
                        GL_MAP2_VERTEX_3
                    );
                finally:
                    gluEndSurface(theNurb);
            finally:
                glPopMatrix();
    def test_errors( self ):
        """Test for error catching/checking"""
        try:
            glClear( GL_INVALID_VALUE )
        except Exception, err:
            assert err.err == 1281, ("""Expected invalid value (1281)""", err.err)
        else:
            raise RuntimeError( """No error on invalid glClear""" )
        try:
            glColorPointer(GL_INVALID_VALUE,GL_BYTE,0,None)
        except Exception, err:
            assert err.err == 1281, ("""Expected invalid value (1281)""", err.err)
            assert err.baseOperation, err.baseOperation
            assert err.pyArgs == (GL_INVALID_VALUE, GL_BYTE, 0, None), err.pyArgs
            assert err.cArgs == (GL_INVALID_VALUE, GL_BYTE, 0, None), err.cArgs
        else:
            raise RuntimeError( """No error on invalid glColorPointer""" )
        try:
            glBitmap(-1,-1,0,0,0,0,"")
        except Exception, err:
            assert err.err in (1281,1282), ("""Expected invalid value (1281) or invalid operation (1282)""", err.err)
        else:
            raise RuntimeError( """No error on invalid glBitmap""" )
    def test_quadrics( self ):
        """Test for rendering quadric objects"""
        quad = gluNewQuadric()
        glColor3f( 1,0, 0 )
        gluSphere( quad, 1.0, 16, 16 )
    if not OpenGL.ERROR_ON_COPY:
        def test_simple( self ):
            """Test for simple vertex-based drawing"""
            glDisable( GL_LIGHTING )
            glBegin( GL_TRIANGLES )
            try:
                try:
                    glVertex3f( 0.,1.,0. )
                except Exception, err:
                    traceback.print_exc()
                glVertex3fv( [-1,0,0] )
                glVertex3dv( [1,0,0] )
                try:
                    glVertex3dv( [1,0] )
                except ValueError, err:
                    #Got expected value error (good)
                    pass
                else:
                    raise RuntimeError(
                        """Should have raised a value error on passing 2-element array to 3-element function!""",
                    )
            finally:
                glEnd()
            a = glGenTextures( 1 )
            assert a
            b = glGenTextures( 2 )
            assert len(b) == 2
    def test_arbwindowpos( self ):
        """Test the ARB window_pos extension will load if available"""
        from OpenGL.GL.ARB.window_pos import glWindowPos2dARB
        if glWindowPos2dARB:
            glWindowPos2dARB( 0.0, 3.0 )
    def test_getstring( self ):
        assert glGetString( GL_EXTENSIONS )
    if not OpenGL.ERROR_ON_COPY:
        def test_pointers( self ):
            """Test that basic pointer functions work"""
            vertex = constants.GLdouble * 3
            vArray =  vertex * 2
            glVertexPointerd( [[2,3,4,5],[2,3,4,5]] )
            glVertexPointeri( ([2,3,4,5],[2,3,4,5]) )
            glVertexPointers( [[2,3,4,5],[2,3,4,5]] )
            glVertexPointerd( vArray( vertex(2,3,4),vertex(2,3,4) ) )
            myVector = vArray( vertex(2,3,4),vertex(2,3,4) )
            glVertexPointer(
                3,
                GL_DOUBLE,
                0,
                ctypes.cast( myVector, ctypes.POINTER(constants.GLdouble)) 
            )
            
            repr(glVertexPointerb( [[2,3],[4,5]] ))
            glVertexPointerf( [[2,3],[4,5]] )
            assert arrays.ArrayDatatype.dataPointer( None ) == None
            glVertexPointerf( None )
            
            glNormalPointerd( [[2,3,4],[2,3,4]] )
            glNormalPointerd( None )
        
            glTexCoordPointerd( [[2,3,4],[2,3,4]] )
            glTexCoordPointerd( None )
        
            glColorPointerd( [[2,3,4],[2,3,4]] )
            glColorPointerd( None )
        
            glEdgeFlagPointerb( [0,1,0,0,1,0] )
            glEdgeFlagPointerb( None )
        
            glIndexPointerd( [0,1,0,0,1,0] )
            glIndexPointerd( None )
            
            glColor4fv( [0,0,0,1] )
            
            # string data-types...
            import struct
            s = struct.pack( '>iiii', 2,3,4,5 ) * 2
            result = glVertexPointer( 4,GL_INT,0,s )
        TESS_TEST_SHAPE = [
                [191,   0],
                [ 191, 1480],
                [ 191, 1480],
                [ 401, 1480],
                [ 401, 1480],
                [401,   856],
                [401,   856],
                [1105,  856],
                [1105,  856],
                [1105, 1480],
                [1105, 1480],
                [1315, 1480],
                [1315, 1480],
                [1315,    0],
                [1315,    0],
                [1105,    0],
                [1105,    0],
                [1105,  699],
                [1105,  699],
                [401,   699],
                [401,   699],
                [401,     0],
                [401,     0],
                [191,     0],
                [191,     0],
                [191,     0],
            ]
        def test_tess(self ):
            """Test that tessellation works"""
            glDisable( GL_LIGHTING )
            glColor3f( 1,1,1 )
            glNormal3f( 0,0,1 )
            def begin( *args ):
                return glBegin( *args )
            def vertex( *args ):
                return glVertex3dv( *args )
            def end( *args ):
                return glEnd( *args )
            def combine( coords, vertex_data, weight):
                return coords
            tobj = gluNewTess()
            gluTessCallback(tobj, GLU_TESS_BEGIN, begin);
            gluTessCallback(tobj, GLU_TESS_VERTEX, vertex); 
            gluTessCallback(tobj, GLU_TESS_END, end); 
            gluTessCallback(tobj, GLU_TESS_COMBINE, combine); 
            gluTessBeginPolygon(tobj, None); 
            gluTessBeginContour(tobj);
            for (x,y) in self.TESS_TEST_SHAPE:
                vert = (x,y,0.0)
                gluTessVertex(tobj, vert, vert);
            gluTessEndContour(tobj); 
            gluTessEndPolygon(tobj);
        def test_texture( self ):
            """Test texture (requires OpenGLContext and PIL)"""
            try:
                from OpenGLContext import texture
                import Image 
                from OpenGL.GLUT import glutSolidTeapot
            except ImportError, err:
                pass
            else:
                glEnable( GL_TEXTURE_2D )
                ourTexture = texture.Texture(
                    Image.open( 'yingyang.png' )
                )
                ourTexture()
                
                glEnable( GL_LIGHTING )
                glEnable( GL_LIGHT0 )
                glBegin( GL_TRIANGLES )
                try:
                    try:
                        glTexCoord2f( .5, 1 )
                        glVertex3f( 0.,1.,0. )
                    except Exception, err:
                        traceback.print_exc()
                    glTexCoord2f( 0, 0 )
                    glVertex3fv( [-1,0,0] )
                    glTexCoord2f( 1, 0 )
                    glVertex3dv( [1,0,0] )
                    try:
                        glVertex3dv( [1,0] )
                    except ValueError, err:
                        #Got expected value error (good)
                        pass
                    else:
                        raise RuntimeError(
                            """Should have raised a value error on passing 2-element array to 3-element function!""",
                        )
                finally:
                    glEnd()
    if array:
        def test_numpyConversion( self ):
            """Test that we can run a numpy conversion from double to float for glColorArray"""
            import numpy
            a = numpy.arange( 0,1.2, .1, 'd' ).reshape( (-1,3 ))
            glEnableClientState(GL_VERTEX_ARRAY)
            try:
                glColorPointerf( a )
                glColorPointerd( a )
            finally:
                glDisableClientState( GL_VERTEX_ARRAY )
    def test_constantPickle( self ):
        """Test that our constants can be pickled/unpickled properly"""
        import pickle, cPickle
        for p in pickle,cPickle:
            v = p.loads( p.dumps( GL_VERTEX_ARRAY ))
            assert v == GL_VERTEX_ARRAY, (v,GL_VERTEX_ARRAY)
            assert v.name == GL_VERTEX_ARRAY.name, v.name 
    
    if not OpenGL.ERROR_ON_COPY:
        def test_copyNonContiguous( self ):
            """Test that a non-contiguous (transposed) array gets applied as a copy"""
            glMatrixMode(GL_MODELVIEW)
            glPushMatrix( )
            try:
                import numpy
                transf = numpy.identity(4, dtype=numpy.float32)
                # some arbitrary transformation...
                transf[0,3] = 2.5
                transf[2,3] = -80
                
                # what do we get with the un-transposed version...
                glMatrixMode(GL_MODELVIEW)
                glLoadIdentity()
                glMultMatrixf(transf)
                untransposed = glGetFloatv(GL_MODELVIEW_MATRIX)
                # now transposed...

                # with a copy it works...
                t2 = transf.transpose().copy()
                # This doesn't work:
                glLoadIdentity()
                glMultMatrixf(t2)
                # This does work:
                #glMultMatrixf(transf.transpose().copy())
                transposed = glGetFloatv(GL_MODELVIEW_MATRIX)

                assert not numpy.allclose( transposed, untransposed ), (transposed, untransposed)
                
                t2 = transf.transpose()
                # This doesn't work:
                glLoadIdentity()
                glMultMatrixf(t2)
                # This does work:
                #glMultMatrixf(transf.transpose().copy())
                transposed = glGetFloatv(GL_MODELVIEW_MATRIX)
                
                assert not numpy.allclose( transposed, untransposed ), (transposed, untransposed)
            finally:
                glMatrixMode(GL_MODELVIEW)
                glPopMatrix()
    def test_nullTexture( self ):
        """Test that we can create null textures"""
        glTexImage2D(GL_TEXTURE_2D, 0, GL_RGB8, 512, 512, 0, GL_RGB, GL_INT, None)
    
    def test_nonFloatColor( self ):
        """Test that we handle non-floating-point colour inputs"""
        for notFloat,shouldWork in ((0,True), (object(),False), (object,False)):
            try:
                glColor4f( 0,1,1,notFloat )
            except Exception, err:
                if shouldWork:
                    raise 
            else:
                if not shouldWork:
                    raise RuntimeError( """Expected failure for non-float value %s, succeeded"""%( notFloat, ))
    someData = [ (0,255,0)]
    def test_glAreTexturesResident( self ):
        """Test that PyOpenGL api for glAreTexturesResident is working
        
        Note: not currently working on AMD64 Linux for some reason
        """
        import numpy
        textures = glGenTextures(2)
        residents = []
        data = numpy.array( self.someData,'i' )
        for texture in textures:
            glBindTexture( GL_TEXTURE_2D,int(texture) )
            glTexImage2D(GL_TEXTURE_2D, 0, GL_RGB8, 1, 1, 0, GL_RGB, GL_INT, data)
            residents.append(
                glGetTexParameteriv(GL_TEXTURE_2D, GL_TEXTURE_RESIDENT )
            )
        error.glCheckError(None)
        result = glAreTexturesResident( textures)
        assert len(result) == 2
        for (tex,expected,found) in zip( textures, residents, result ):
            if expected != found:
                print 'Warning: texture %s residence expected %s got %s'%( tex, expected, found )
        
    if OpenGL.ALLOW_NUMPY_SCALARS:
        def test_passBackResults( self ):
            """Test ALLOW_NUMPY_SCALARS to allow numpy scalars to be passed in"""
            textures = glGenTextures(2)
            glBindTexture( GL_TEXTURE_2D, textures[0] )
    if array:
        def test_arrayTranspose( self ):
            import numpy
            m = glGetFloatv( GL_MODELVIEW_MATRIX )
            glMatrixMode( GL_MODELVIEW )
            glLoadIdentity()

            t = eye(4)
            t[3,0] = 20.0

            # the following glMultMatrixf call ignored this transpose
            t = t.T

            glMultMatrixf( t )

            m = glGetFloatv( GL_MODELVIEW_MATRIX )
            assert numpy.allclose( m[-1], [0,0,0,1] ), m
    def test_glreadpixelsf( self ):
        """Issue #1979002 crash due to mis-calculation of resulting array size"""
        width,height = self.width, self.height
        readback_image1 = glReadPixelsub(0,0,width,height,GL_RGB)
        readback_image2 = glReadPixelsf(0,0,width,height,GL_RGB)
    def test_glreadpixels_is_string( self ):
        """Issue #1959860 incompatable change to returning arrays reversed"""
        width,height = self.width, self.height
        readback_image1 = glReadPixels(0,0,width,height,GL_RGB, GL_UNSIGNED_BYTE)
        assert isinstance( readback_image1, str ), type( readback_image1 )
        readback_image1 = glReadPixels(0,0,width,height,GL_RGB, GL_BYTE)
        assert not isinstance( readback_image1, str ), type(readback_image2)
    
    if array:
        def test_glreadpixels_warray( self ):
            """SF#1311265 allow passing in the array object"""
            width,height = self.width, self.height
            data = zeros( (width,height,3), 'B' )
            image1 = glReadPixelsub(0,0,width,height,GL_RGB,array=data)
            
        def test_mmap_data( self ):
            """Test that we can use mmap data array
            
            If we had a reasonable lib that dumped raw image data to a shared-mem file
            we might be able to use this for movie display :) 
            """
            fh = open( 'mmap-test-data.dat', 'w+' )
            fh.write( '\000'*(32*32*3+1))
            fh.flush()
            fh.close()
            # using numpy.memmap here...
            data = memmap( 'mmap-test-data.dat' )
            for i in range( 0,255,2 ):
                glDrawPixels( 32,32, GL_RGB, GL_UNSIGNED_BYTE, data, )
                glFlush()
                pygame.display.flip()
                data[::2] = i
                time.sleep( 0.001 )
    
    if array:
        def test_vbo( self ):
            """Test utility vbo wrapper"""
            import numpy
            from OpenGL.arrays import vbo
            assert vbo.get_implementation()
            dt = arraydatatype.GLdoubleArray
            array = numpy.array( [
                [0,0,0],
                [0,1,0],
                [1,.5,0],
                [1,0,0],
                [1.5,.5,0],
                [1.5,0,0],
            ], dtype='d')
            indices = numpy.array(
                range(len(array)),
                'i',
            )
            d = vbo.VBO(array)
            glDisable( GL_CULL_FACE )
            glNormal3f( 0,0,1 )
            glColor3f( 1,1,1 )
            glEnableClientState(GL_VERTEX_ARRAY)
            try:
                for x in range( 1, 255, 10 ):
                    d.bind()
                    try:
                        glVertexPointerd( d )
                        glDrawElements( GL_LINE_LOOP, len(indices), GL_UNSIGNED_INT, indices )
                    finally:
                        d.unbind()
                    lastPoint = numpy.array( [[1.5,(1/255.) * float(x),0]] )
                    d[-2:-1] = lastPoint
                    glFlush()
                    pygame.display.flip()
                    glClear( GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT )
                    time.sleep( 0.001 )
            finally:
                glDisableClientState( GL_VERTEX_ARRAY )
            # bug report from Dan Helfman, delete shouldn't cause 
            # errors if called explicitly
            d.delete()
    def test_fbo( self ):
        """Test that we support framebuffer objects
        
        http://www.gamedev.net/reference/articles/article2331.asp
        """
        if not glGenFramebuffers:
            return False
        width = height = 128
        fbo = glGenFramebuffers(1)
        glBindFramebuffer(GL_FRAMEBUFFER, fbo)
        depthbuffer = glGenRenderbuffers(1 )
        glBindRenderbuffer(GL_RENDERBUFFER, depthbuffer)
        glRenderbufferStorage(GL_RENDERBUFFER, GL_DEPTH_COMPONENT24, width, height)
        glFramebufferRenderbuffer(
            GL_FRAMEBUFFER, GL_DEPTH_ATTACHMENT, GL_RENDERBUFFER, 
            depthbuffer
        )
        img = glGenTextures(1)
        glBindTexture(GL_TEXTURE_2D, img)
        # NOTE: these lines are *key*, without them you'll likely get an unsupported format error,
        # ie. GL_FRAMEBUFFER_UNSUPPORTED
        glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_NEAREST);
        glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_NEAREST);
        glTexImage2D(
            GL_TEXTURE_2D, 0, GL_RGB8,  
            width, height, 0, GL_RGB, 
            GL_INT, 
            None # no data transferred
        ) 
        glFramebufferTexture2D(
            GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, 
            img, 
            0 # mipmap level, normally 0
        )
        status = glCheckFramebufferStatus(GL_FRAMEBUFFER)
        assert status == GL_FRAMEBUFFER_COMPLETE, status
        glBindFramebuffer(GL_FRAMEBUFFER, fbo)
        glPushAttrib(GL_VIEWPORT_BIT) # viewport is shared with the main context
        try:
            glViewport(0,0,width, height)
            
            # rendering to the texture here...
            glColor3f( 1,0,0 )
            glNormal3f( 0,0,1 )
            glBegin( GL_QUADS )
            for v in [[0,0,0],[0,1,0],[1,1,0],[1,0,0]]:
                glColor3f( *v )
                glVertex3d( *v )
            glEnd()
        finally:
            glPopAttrib(); # restore viewport
        glBindFramebuffer(GL_FRAMEBUFFER, 0) # unbind
        
        glBindTexture(GL_TEXTURE_2D, img)
        
        glEnable( GL_TEXTURE_2D )
        
        # rendering with the texture here...
        glColor3f( 1,1,1 )
        glNormal3f( 0,0,1 )
        glDisable( GL_LIGHTING )
        glBegin( GL_QUADS )
        try:
            for v in [[0,0,0],[0,1,0],[1,1,0],[1,0,0]]:
                glTexCoord2f( *v[:2] )
                glVertex3d( *v )
        finally:
            glEnd()
    def test_gl_1_2_support( self ):
        if glBlendColor:
            glBlendColor( .3, .4, 1.0, .3 )
            print 'OpenGL 1.2 support'
    if array:
        def test_glmultidraw( self ):
            """Test that glMultiDrawElements works, uses glDrawElements"""
            if glMultiDrawElements:
                points = array([
                    (i,0,0) for i in range( 8 )
                ] + [
                    (i,1,0) for i in range( 8 )
                ], 'd')
                indices = array([
                    [0,8,9,1, 2,10,11,3,],
                    [4,12,13,5,6,14,15,7],
                ],'B')
                counts = [ len(x) for x in indices ]
                glEnableClientState( GL_VERTEX_ARRAY )
                glDisableClientState( GL_COLOR_ARRAY )
                glDisableClientState( GL_NORMAL_ARRAY )
                try:
                    glVertexPointerd( points )
                    glDisable( GL_LIGHTING )
                    try:
                        glMultiDrawElements(GL_QUAD_STRIP, counts, GL_UNSIGNED_BYTE, indices, 2)
                    finally:
                        glEnable( GL_LIGHTING )
                finally:
                    glDisableClientState( GL_VERTEX_ARRAY )
            else:
                print 'No multi_draw_arrays support'
    def test_glDrawBuffers_list( self ):
        """Test that glDrawBuffers with list argument doesn't crash"""
        a_type = constants.GLenum*2
        args = a_type(
            GL_COLOR_ATTACHMENT0,
            GL_COLOR_ATTACHMENT1,
        )
        try:
            glDrawBuffers( 2, args )
        except GLError, err:
            assert err.err == GL_INVALID_OPERATION, err
    def test_glDrawBuffers_list_valid( self ):
        """Test that glDrawBuffers with list argument where value is set"""
        previous = glGetIntegerv( GL_READ_BUFFER )
        fbo = glGenFramebuffers(1)
        glBindFramebuffer(GL_FRAMEBUFFER, fbo)
        try:
            img1,img2 = glGenTextures(2)
            for img in img1,img2:
                glBindTexture( GL_TEXTURE_2D, img )
                glTexImage2D(
                    GL_TEXTURE_2D, 0, GL_RGB8,  
                    300, 300, 0, GL_RGB, 
                    GL_INT, 
                    None # no data transferred
                ) 
            

            glFramebufferTexture2D(
                GL_FRAMEBUFFER, 
                GL_COLOR_ATTACHMENT0, 
                GL_TEXTURE_2D, img1, 0
            )
            glFramebufferTexture2D(
                GL_FRAMEBUFFER, 
                GL_COLOR_ATTACHMENT1, 
                GL_TEXTURE_2D, img2, 0
            )
            a_type = constants.GLenum*2
            drawingBuffers = a_type(
                GL_COLOR_ATTACHMENT0, 
                GL_COLOR_ATTACHMENT1,
            )
            glDrawBuffers(2, drawingBuffers )
            try:
                checkFramebufferStatus()
            except error.GLError, err:
                pass
            else:
                glReadBuffer( GL_COLOR_ATTACHMENT1 )
                pixels = glReadPixels( 0,0, 10,10, GL_RGB, GL_UNSIGNED_BYTE )
                assert len(pixels) == 300, len(pixels)
        finally:
            glBindFramebuffer( GL_FRAMEBUFFER, 0 )
        
        glReadBuffer( previous )
        
    def test_enable_histogram( self ):
        if glInitImagingARB():
            glHistogram(GL_HISTOGRAM, 256, GL_LUMINANCE, GL_FALSE)
            glEnable( GL_HISTOGRAM )
            glDisable( GL_HISTOGRAM )
        else:
            print 'No ARB imaging extension'
    if not OpenGL.ERROR_ON_COPY:
        def test_gluNurbsCurve( self ):
            """Test that gluNurbsCurve raises error on invalid arguments"""
            nurb = gluNewNurbsRenderer()
            gluBeginCurve( nurb )
            self.failUnlessRaises( error.GLUerror,
                gluNurbsCurve,
                    nurb, 
                    [0, 1.0],
                    [[0,0,0],[1,0,0],[1,1,0]],
                    GL_MAP1_VERTEX_3,
            )
            self.failUnlessRaises( error.GLUerror,
                gluNurbsCurve,
                    nurb, 
                    [],
                    [[0,0,0],[1,0,0],[1,1,0]],
                    GL_MAP1_VERTEX_3,
            )
            self.failUnlessRaises( error.GLUerror,
                gluNurbsCurve,
                    nurb, 
                    [],
                    [],
                    GL_MAP1_VERTEX_3,
            )
    def test_get_version( self ):
        from OpenGL.extensions import getGLVersion
        version = getGLVersion()
        if version >= [2,0]:
            assert glShaderSource
            assert glUniform1f
        else:
            assert not glShaderSource
            assert not glUniform1f
    
    def test_tess_collection( self ):
        """SF#2354596 tessellation combine results collected"""
        def tessvertex(vertex_data, polygon_data):
            polygon_data.append(vertex_data)

        def tesscombine(coords, vertex_data, weight):
            return (True,coords)	# generated vertices marked as True

        def tessedge(flag):
            pass	# dummy
        collected=[]	# collect triangle vertices

        # set up tessellator in CSG intersection mode
        tess=gluNewTess()
        gluTessProperty(tess, GLU_TESS_WINDING_RULE, GLU_TESS_WINDING_ABS_GEQ_TWO)
        gluTessCallback(tess, GLU_TESS_VERTEX_DATA,  tessvertex)
        gluTessCallback(tess, GLU_TESS_COMBINE,      tesscombine)
        gluTessCallback(tess, GLU_TESS_EDGE_FLAG,    tessedge)	# no strips

        gluTessBeginPolygon(tess, collected)

        # First square
        gluTessBeginContour(tess)
        gluTessVertex(tess, [-1,0,-1], (False,[-1,0,-1]))
        gluTessVertex(tess, [ 1,0,-1], (False,[ 1,0,-1]))
        gluTessVertex(tess, [ 1,0, 1], (False,[ 1,0, 1]))
        gluTessVertex(tess, [-1,0, 1], (False,[-1,0, 1]))
        gluTessEndContour(tess)

        # Second square, intersects with first
        gluTessBeginContour(tess)
        gluTessVertex(tess, [0.5,0,-0.5], (False,[0.5,0,-0.5]))
        gluTessVertex(tess, [1.5,0,-0.5], (False,[1.5,0,-0.5]))
        gluTessVertex(tess, [1.5,0, 0.5], (False,[1.5,0, 0.5]))
        gluTessVertex(tess, [0.5,0, 0.5], (False,[0.5,0, 0.5]))
        gluTessEndContour(tess)

        gluTessEndPolygon(tess)

        # Show collected triangle vertices :-
        # Original input vertices are marked as False.
        # Vertices generated in combine callback are marked as True.
        assert collected
    
    def test_get_boolean_bitmap( self ):
        # should not raise error
        value = glGetBoolean(GL_TEXTURE_2D)
    if array:
        def test_draw_bitmap_pixels( self ):
            """SF#2152623 Drawing pixels as bitmaps (bits)"""
            pixels = array([0,0,0,0,0,0,0,0],'B')
            glDrawPixels( 8,8, GL_COLOR_INDEX, GL_BITMAP, pixels )
    
    def test_glCallLists_twice2( self ):
        """SF#2829309 report that glCallLists doubles operation"""
        glRenderMode (GL_RENDER)
        glMatrixMode(GL_PROJECTION)
        glLoadIdentity()
        gluPerspective(40.0, 1.0, 1.0, 10.0)
        glMatrixMode (GL_MODELVIEW)
        glLoadIdentity ()
        glTranslatef (0, 0, -3)
        first = glGenLists( 2 )
        second = first+1

        glNewList(first, GL_COMPILE_AND_EXECUTE)
        glInitNames ()
        glCallLists([second]) # replace with gCallList(2)
        #glCallList(second)
        glEndList ()

        glNewList(second, GL_COMPILE)
        glPushName (1)
        glBegin (GL_POINTS)
        glVertex3f (0, 0, 0)
        glEnd ()
        glEndList ()
        glCallList( second )
        glPopName()
        depth = glGetIntegerv( GL_NAME_STACK_DEPTH )
        assert depth == (0,), depth # have popped, but even then, were' not in the mode...

        glSelectBuffer (100)
        glRenderMode (GL_SELECT)
        glCallList(1)
        depth = glGetIntegerv( GL_NAME_STACK_DEPTH )
        assert depth == (1,), depth # should have a single record
        glPopName()
        records = glRenderMode (GL_RENDER)
        # reporter says sees two records, Linux sees none, Win32 sees 1 :(
        assert len(records) == 1, records
    
    def test_get_max_tex_units( self ):
        """SF#2895081 glGetIntegerv( GL_MAX_TEXTURE_IMAGE_UNITS )"""
        units = glGetIntegerv( GL_MAX_TEXTURE_IMAGE_UNITS )
        
        
if __name__ == "__main__":
    unittest.main()
    pygame.display.quit()
    pygame.quit()



"""Wrapper/Implementation of the GLU tessellator objects for PyOpenGL"""
from OpenGL.raw import GLU as simple
from OpenGL.platform import GLU,createBaseFunction
from OpenGL.GLU import glustruct
from OpenGL import arrays, constants
from OpenGL.platform import PLATFORM
from OpenGL.lazywrapper import lazy
import ctypes

class GLUtesselator( glustruct.GLUStruct, simple.GLUtesselator):
    """Implementation class for GLUTessellator structures in OpenGL-ctypes"""
    FUNCTION_TYPE = PLATFORM.functionTypeFor(PLATFORM.GLU)
    CALLBACK_TYPES = {
        # mapping from "which" GLU enumeration to a ctypes function type
        simple.GLU_TESS_BEGIN: FUNCTION_TYPE( None, simple.GLenum ),
        simple.GLU_TESS_BEGIN_DATA: FUNCTION_TYPE( 
            None, simple.GLenum, ctypes.c_void_p 
        ),
        simple.GLU_TESS_EDGE_FLAG: FUNCTION_TYPE( None, simple.GLboolean),
        simple.GLU_TESS_EDGE_FLAG_DATA: FUNCTION_TYPE( 
            None, simple.GLboolean, ctypes.c_void_p 
        ),
        simple.GLU_TESS_VERTEX: FUNCTION_TYPE( None, ctypes.c_void_p ),
        simple.GLU_TESS_VERTEX_DATA: FUNCTION_TYPE( 
            None, ctypes.c_void_p, ctypes.c_void_p
        ),
        simple.GLU_TESS_END: FUNCTION_TYPE( None ),
        simple.GLU_TESS_END_DATA: FUNCTION_TYPE( None, ctypes.c_void_p), 
        simple.GLU_TESS_COMBINE: FUNCTION_TYPE( 
            None, 
            ctypes.POINTER(simple.GLdouble), 
            ctypes.POINTER(ctypes.c_void_p), 
            ctypes.POINTER(simple.GLfloat),
            ctypes.POINTER(ctypes.c_void_p)
        ),
        simple.GLU_TESS_COMBINE_DATA: FUNCTION_TYPE( 
            None, 
            ctypes.POINTER(simple.GLdouble), 
            ctypes.POINTER(ctypes.c_void_p), 
            ctypes.POINTER(simple.GLfloat),
            ctypes.POINTER(ctypes.c_void_p),
            ctypes.c_void_p,
        ),
        simple.GLU_TESS_ERROR: FUNCTION_TYPE( None, simple.GLenum), 
        simple.GLU_TESS_ERROR_DATA: FUNCTION_TYPE( 
            None, simple.GLenum, ctypes.c_void_p
        ), 
        simple.GLU_ERROR : FUNCTION_TYPE( None, simple.GLenum )
    }
    WRAPPER_METHODS = {
        simple.GLU_TESS_BEGIN_DATA: 'dataWrapper',
        simple.GLU_TESS_EDGE_FLAG_DATA: 'dataWrapper',
        simple.GLU_TESS_VERTEX: 'vertexWrapper',
        simple.GLU_TESS_VERTEX_DATA: 'vertexWrapper',
        simple.GLU_TESS_END_DATA: 'dataWrapper', 
        simple.GLU_TESS_COMBINE: 'combineWrapper',
        simple.GLU_TESS_COMBINE_DATA: 'combineWrapper',
        simple.GLU_TESS_ERROR_DATA: 'dataWrapper', 
    }
    def gluTessVertex( self, location, data=None ):
        """Add a vertex to this tessellator, storing data for later lookup"""
        vertexCache = getattr( self, 'vertexCache', None )
        if vertexCache is None:
            self.vertexCache = []
            vertexCache = self.vertexCache
        location = arrays.GLdoubleArray.asArray( location, constants.GL_DOUBLE )
        if arrays.GLdoubleArray.arraySize( location ) != 3:
            raise ValueError( """Require 3 doubles for array location, got: %s"""%(location,))
        oorValue = self.noteObject(data)
        vp = ctypes.c_void_p( oorValue )
        self.vertexCache.append( location )
        return gluTessVertexBase( self, location, vp )
    def gluTessBeginPolygon( self, data ):
        """Note the object pointer to return it as a Python object"""
        return simple.gluTessBeginPolygon( 
            self, ctypes.c_void_p(self.noteObject( data ))
        )
    def combineWrapper( self, function ):
        """Wrap a Python function with ctypes-compatible wrapper for combine callback
        
        For a Python combine callback, the signature looks like this:
            def combine(
                GLdouble coords[3], 
                void *vertex_data[4], 
                GLfloat weight[4]
            ):
                return data
        While the C signature looks like this:
            void combine( 
                GLdouble coords[3], 
                void *vertex_data[4], 
                GLfloat weight[4], 
                void **outData 
            )
        """
        if (function is not None) and (not hasattr( function,'__call__' )):
            raise TypeError( """Require a callable callback, got:  %s"""%(function,))
        def wrap( coords, vertex_data, weight, outData, *args ):
            """The run-time wrapper around the function"""
            coords = self.ptrAsArray( coords, 3, arrays.GLdoubleArray )
            weight = self.ptrAsArray( weight, 4, arrays.GLfloatArray )
            # find the original python objects for vertex data
            vertex_data = [ self.originalObject( vertex_data[i] ) for i in range(4) ]
            args = tuple( [ self.originalObject( x ) for x in args ] )
            try:
                result = function( coords, vertex_data, weight, *args )
            except Exception, err:
                raise err.__class__(
                    """Failure during combine callback %r with args( %s,%s,%s,*%s):\n%s"""%(
                        function, coords, vertex_data, weight, args, str(err),
                    )
                )
            outP = ctypes.c_void_p(self.noteObject(result))
            outData[0] = outP
            return None
        return wrap
    def dataWrapper( self, function ):
        """Wrap a function which only has the one data-pointer as last arg"""
        if (function is not None) and (not hasattr( function,'__call__' )):
            raise TypeError( """Require a callable callback, got:  %s"""%(function,))
        def wrap( *args ):
            """Just return the original object for polygon_data"""
            args = args[:-1] + ( self.originalObject(args[-1]), )
            try:
                return function( *args )
            except Exception, err:
                err.args += (function,args)
                raise
        return wrap
    def dataWrapper2( self, function ):
        """Wrap a function which has two data-pointers as last args"""
        if (function is not None) and (not hasattr( function,'__call__' )):
            raise TypeError( """Require a callable callback, got:  %s"""%(function,))
        def wrap( *args ):
            """Just return the original object for polygon_data"""
            args = args[:-2] + ( self.originalObject(args[-2]), self.originalObject(args[-1]), )
            try:
                return function( *args )
            except Exception, err:
                err.args += (function,args)
                raise
        return wrap
    def vertexWrapper( self, function ):
        """Converts a vertex-pointer into an OOR vertex for processing"""
        if (function is not None) and (not hasattr( function,'__call__' )):
            raise TypeError( """Require a callable callback, got:  %s"""%(function,))
        def wrap( vertex, data=None ):
            """Just return the original object for polygon_data"""
            vertex = self.originalObject(vertex)
            try:
                if data is not None:
                    data = self.originalObject(data)
                    return function( vertex, data )
                else:
                    return function( vertex )
            except Exception, err:
                err.args += (function,(vertex,data))
                raise
        return wrap

GLUtesselator.CALLBACK_FUNCTION_REGISTRARS = dict([
    (c,createBaseFunction( 
        'gluTessCallback', dll=GLU, resultType=None, 
        argTypes=[ctypes.POINTER(GLUtesselator), simple.GLenum,funcType],
        doc='gluTessCallback( POINTER(GLUtesselator)(tess), GLenum(which), _GLUfuncptr(CallBackFunc) ) -> None', 
        argNames=('tess', 'which', 'CallBackFunc'),
    ))
    for (c,funcType) in GLUtesselator.CALLBACK_TYPES.items()
])
del c, funcType

def gluTessCallback( tess, which, function ):
    """Set a given gluTessellator callback for the given tessellator"""
    return tess.addCallback( which, function )
def gluTessBeginPolygon( tess, data ):
    """Start definition of polygon in the tessellator"""
    return tess.gluTessBeginPolygon( data )
def gluTessVertex( tess, location, data=None ):
    """Add a vertex to the tessellator's current polygon"""
    return tess.gluTessVertex( location, data )

# /usr/include/GL/glu.h 293
@lazy( 
    createBaseFunction( 
        'gluNewTess', dll=GLU, resultType=ctypes.POINTER(GLUtesselator), 
        doc='gluNewTess(  ) -> POINTER(GLUtesselator)', 
    ) 
)
def gluNewTess( baseFunction ):
    """Get a new tessellator object (just unpacks the pointer for you)"""
    return baseFunction()[0]

@lazy( simple.gluGetTessProperty )
def gluGetTessProperty( baseFunction, tess, which, data=None ):
    """Retrieve single double for a tessellator property"""
    if data is None:
        data = simple.GLdouble( 0.0 )
        baseFunction( tess, which, data )
        return data.value 
    else:
        return baseFunction( tess, which, data )

gluTessVertexBase = arrays.setInputArraySizeType(
    simple.gluTessVertex,
    3,
    arrays.GLdoubleArray,
    'location',
)

__all__ = (
    'gluNewTess',
    'gluGetTessProperty',
    'gluTessBeginPolygon',
    'gluTessCallback',
    'gluTessVertex',
)



'''OpenGL extension VERSION.GL_3_0_DEPRECATED

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_3_0'
_DEPRECATED = True
GL_CLAMP_VERTEX_COLOR = constant.Constant( 'GL_CLAMP_VERTEX_COLOR', 0x891A )
GL_CLAMP_FRAGMENT_COLOR = constant.Constant( 'GL_CLAMP_FRAGMENT_COLOR', 0x891B )
GL_ALPHA_INTEGER = constant.Constant( 'GL_ALPHA_INTEGER', 0x8D97 )




'''OpenGL extension EXT.coordinate_frame

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_coordinate_frame'
_DEPRECATED = False
GL_TANGENT_ARRAY_EXT = constant.Constant( 'GL_TANGENT_ARRAY_EXT', 0x8439 )
glget.addGLGetConstant( GL_TANGENT_ARRAY_EXT, (1,) )
GL_BINORMAL_ARRAY_EXT = constant.Constant( 'GL_BINORMAL_ARRAY_EXT', 0x843A )
GL_CURRENT_TANGENT_EXT = constant.Constant( 'GL_CURRENT_TANGENT_EXT', 0x843B )
glget.addGLGetConstant( GL_CURRENT_TANGENT_EXT, (1,) )
GL_CURRENT_BINORMAL_EXT = constant.Constant( 'GL_CURRENT_BINORMAL_EXT', 0x843C )
glget.addGLGetConstant( GL_CURRENT_BINORMAL_EXT, (1,) )
GL_TANGENT_ARRAY_TYPE_EXT = constant.Constant( 'GL_TANGENT_ARRAY_TYPE_EXT', 0x843E )
glget.addGLGetConstant( GL_TANGENT_ARRAY_TYPE_EXT, (1,) )
GL_TANGENT_ARRAY_STRIDE_EXT = constant.Constant( 'GL_TANGENT_ARRAY_STRIDE_EXT', 0x843F )
glget.addGLGetConstant( GL_TANGENT_ARRAY_STRIDE_EXT, (1,) )
GL_BINORMAL_ARRAY_TYPE_EXT = constant.Constant( 'GL_BINORMAL_ARRAY_TYPE_EXT', 0x8440 )
glget.addGLGetConstant( GL_BINORMAL_ARRAY_TYPE_EXT, (1,) )
GL_BINORMAL_ARRAY_STRIDE_EXT = constant.Constant( 'GL_BINORMAL_ARRAY_STRIDE_EXT', 0x8441 )
glget.addGLGetConstant( GL_BINORMAL_ARRAY_STRIDE_EXT, (1,) )
GL_TANGENT_ARRAY_POINTER_EXT = constant.Constant( 'GL_TANGENT_ARRAY_POINTER_EXT', 0x8442 )
GL_BINORMAL_ARRAY_POINTER_EXT = constant.Constant( 'GL_BINORMAL_ARRAY_POINTER_EXT', 0x8443 )
GL_MAP1_TANGENT_EXT = constant.Constant( 'GL_MAP1_TANGENT_EXT', 0x8444 )
GL_MAP2_TANGENT_EXT = constant.Constant( 'GL_MAP2_TANGENT_EXT', 0x8445 )
GL_MAP1_BINORMAL_EXT = constant.Constant( 'GL_MAP1_BINORMAL_EXT', 0x8446 )
GL_MAP2_BINORMAL_EXT = constant.Constant( 'GL_MAP2_BINORMAL_EXT', 0x8447 )
glTangent3bEXT = platform.createExtensionFunction( 
'glTangent3bEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLbyte,constants.GLbyte,constants.GLbyte,),
doc='glTangent3bEXT(GLbyte(tx), GLbyte(ty), GLbyte(tz)) -> None',
argNames=('tx','ty','tz',),
deprecated=_DEPRECATED,
)

glTangent3bvEXT = platform.createExtensionFunction( 
'glTangent3bvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLbyteArray,),
doc='glTangent3bvEXT(GLbyteArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glTangent3dEXT = platform.createExtensionFunction( 
'glTangent3dEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glTangent3dEXT(GLdouble(tx), GLdouble(ty), GLdouble(tz)) -> None',
argNames=('tx','ty','tz',),
deprecated=_DEPRECATED,
)

glTangent3dvEXT = platform.createExtensionFunction( 
'glTangent3dvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLdoubleArray,),
doc='glTangent3dvEXT(GLdoubleArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glTangent3fEXT = platform.createExtensionFunction( 
'glTangent3fEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glTangent3fEXT(GLfloat(tx), GLfloat(ty), GLfloat(tz)) -> None',
argNames=('tx','ty','tz',),
deprecated=_DEPRECATED,
)

glTangent3fvEXT = platform.createExtensionFunction( 
'glTangent3fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,),
doc='glTangent3fvEXT(GLfloatArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glTangent3iEXT = platform.createExtensionFunction( 
'glTangent3iEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLint,constants.GLint,),
doc='glTangent3iEXT(GLint(tx), GLint(ty), GLint(tz)) -> None',
argNames=('tx','ty','tz',),
deprecated=_DEPRECATED,
)

glTangent3ivEXT = platform.createExtensionFunction( 
'glTangent3ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLintArray,),
doc='glTangent3ivEXT(GLintArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glTangent3sEXT = platform.createExtensionFunction( 
'glTangent3sEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glTangent3sEXT(GLshort(tx), GLshort(ty), GLshort(tz)) -> None',
argNames=('tx','ty','tz',),
deprecated=_DEPRECATED,
)

glTangent3svEXT = platform.createExtensionFunction( 
'glTangent3svEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLshortArray,),
doc='glTangent3svEXT(GLshortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glBinormal3bEXT = platform.createExtensionFunction( 
'glBinormal3bEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLbyte,constants.GLbyte,constants.GLbyte,),
doc='glBinormal3bEXT(GLbyte(bx), GLbyte(by), GLbyte(bz)) -> None',
argNames=('bx','by','bz',),
deprecated=_DEPRECATED,
)

glBinormal3bvEXT = platform.createExtensionFunction( 
'glBinormal3bvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLbyteArray,),
doc='glBinormal3bvEXT(GLbyteArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glBinormal3dEXT = platform.createExtensionFunction( 
'glBinormal3dEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glBinormal3dEXT(GLdouble(bx), GLdouble(by), GLdouble(bz)) -> None',
argNames=('bx','by','bz',),
deprecated=_DEPRECATED,
)

glBinormal3dvEXT = platform.createExtensionFunction( 
'glBinormal3dvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLdoubleArray,),
doc='glBinormal3dvEXT(GLdoubleArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glBinormal3fEXT = platform.createExtensionFunction( 
'glBinormal3fEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glBinormal3fEXT(GLfloat(bx), GLfloat(by), GLfloat(bz)) -> None',
argNames=('bx','by','bz',),
deprecated=_DEPRECATED,
)

glBinormal3fvEXT = platform.createExtensionFunction( 
'glBinormal3fvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,),
doc='glBinormal3fvEXT(GLfloatArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glBinormal3iEXT = platform.createExtensionFunction( 
'glBinormal3iEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLint,constants.GLint,),
doc='glBinormal3iEXT(GLint(bx), GLint(by), GLint(bz)) -> None',
argNames=('bx','by','bz',),
deprecated=_DEPRECATED,
)

glBinormal3ivEXT = platform.createExtensionFunction( 
'glBinormal3ivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLintArray,),
doc='glBinormal3ivEXT(GLintArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glBinormal3sEXT = platform.createExtensionFunction( 
'glBinormal3sEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glBinormal3sEXT(GLshort(bx), GLshort(by), GLshort(bz)) -> None',
argNames=('bx','by','bz',),
deprecated=_DEPRECATED,
)

glBinormal3svEXT = platform.createExtensionFunction( 
'glBinormal3svEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLshortArray,),
doc='glBinormal3svEXT(GLshortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glTangentPointerEXT = platform.createExtensionFunction( 
'glTangentPointerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glTangentPointerEXT(GLenum(type), GLsizei(stride), c_void_p(pointer)) -> None',
argNames=('type','stride','pointer',),
deprecated=_DEPRECATED,
)

glBinormalPointerEXT = platform.createExtensionFunction( 
'glBinormalPointerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glBinormalPointerEXT(GLenum(type), GLsizei(stride), c_void_p(pointer)) -> None',
argNames=('type','stride','pointer',),
deprecated=_DEPRECATED,
)


def glInitCoordinateFrameEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension HP.texture_lighting

This module customises the behaviour of the 
OpenGL.raw.GL.HP.texture_lighting to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines a mechanism for applications to request
	that color originating from specular lighting be added to
	the fragment color _after_ texture application.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/HP/texture_lighting.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.HP.texture_lighting import *
### END AUTOGENERATED SECTION


'''OpenGL extension EXT.abgr

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.abgr to provide a more 
Python-friendly API

Overview (from the spec)
	
	EXT_abgr extends the list of host-memory color formats.  Specifically,
	it provides a reverse-order alternative to image format RGBA.  The ABGR
	component order matches the cpack Iris GL format on big-endian machines.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/abgr.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.EXT.abgr import *
### END AUTOGENERATED SECTION


'''OpenGL extension DFX.multisample

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_DFX_multisample'
_DEPRECATED = False
GL_MULTISAMPLE_3DFX = constant.Constant( 'GL_MULTISAMPLE_3DFX', 0x86B2 )
glget.addGLGetConstant( GL_MULTISAMPLE_3DFX, (1,) )
GL_SAMPLE_BUFFERS_3DFX = constant.Constant( 'GL_SAMPLE_BUFFERS_3DFX', 0x86B3 )
glget.addGLGetConstant( GL_SAMPLE_BUFFERS_3DFX, (1,) )
GL_SAMPLES_3DFX = constant.Constant( 'GL_SAMPLES_3DFX', 0x86B4 )
glget.addGLGetConstant( GL_SAMPLES_3DFX, (1,) )
GL_MULTISAMPLE_BIT_3DFX = constant.Constant( 'GL_MULTISAMPLE_BIT_3DFX', 0x20000000 )


def glInitMultisampleDFX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.stencil_two_side

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_stencil_two_side'
_DEPRECATED = False
GL_STENCIL_TEST_TWO_SIDE_EXT = constant.Constant( 'GL_STENCIL_TEST_TWO_SIDE_EXT', 0x8910 )
glget.addGLGetConstant( GL_STENCIL_TEST_TWO_SIDE_EXT, (1,) )
GL_ACTIVE_STENCIL_FACE_EXT = constant.Constant( 'GL_ACTIVE_STENCIL_FACE_EXT', 0x8911 )
glget.addGLGetConstant( GL_ACTIVE_STENCIL_FACE_EXT, (1,) )
glActiveStencilFaceEXT = platform.createExtensionFunction( 
'glActiveStencilFaceEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glActiveStencilFaceEXT(GLenum(face)) -> None',
argNames=('face',),
deprecated=_DEPRECATED,
)


def glInitStencilTwoSideEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.point_sprite

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_point_sprite'
_DEPRECATED = False
GL_POINT_SPRITE_ARB = constant.Constant( 'GL_POINT_SPRITE_ARB', 0x8861 )
glget.addGLGetConstant( GL_POINT_SPRITE_ARB, (1,) )
GL_COORD_REPLACE_ARB = constant.Constant( 'GL_COORD_REPLACE_ARB', 0x8862 )


def glInitPointSpriteARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.multisample

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_multisample'
_DEPRECATED = False
GL_MULTISAMPLE_ARB = constant.Constant( 'GL_MULTISAMPLE_ARB', 0x809D )
glget.addGLGetConstant( GL_MULTISAMPLE_ARB, (1,) )
GL_SAMPLE_ALPHA_TO_COVERAGE_ARB = constant.Constant( 'GL_SAMPLE_ALPHA_TO_COVERAGE_ARB', 0x809E )
glget.addGLGetConstant( GL_SAMPLE_ALPHA_TO_COVERAGE_ARB, (1,) )
GL_SAMPLE_ALPHA_TO_ONE_ARB = constant.Constant( 'GL_SAMPLE_ALPHA_TO_ONE_ARB', 0x809F )
glget.addGLGetConstant( GL_SAMPLE_ALPHA_TO_ONE_ARB, (1,) )
GL_SAMPLE_COVERAGE_ARB = constant.Constant( 'GL_SAMPLE_COVERAGE_ARB', 0x80A0 )
glget.addGLGetConstant( GL_SAMPLE_COVERAGE_ARB, (1,) )
GL_SAMPLE_BUFFERS_ARB = constant.Constant( 'GL_SAMPLE_BUFFERS_ARB', 0x80A8 )
glget.addGLGetConstant( GL_SAMPLE_BUFFERS_ARB, (1,) )
GL_SAMPLES_ARB = constant.Constant( 'GL_SAMPLES_ARB', 0x80A9 )
glget.addGLGetConstant( GL_SAMPLES_ARB, (1,) )
GL_SAMPLE_COVERAGE_VALUE_ARB = constant.Constant( 'GL_SAMPLE_COVERAGE_VALUE_ARB', 0x80AA )
glget.addGLGetConstant( GL_SAMPLE_COVERAGE_VALUE_ARB, (1,) )
GL_SAMPLE_COVERAGE_INVERT_ARB = constant.Constant( 'GL_SAMPLE_COVERAGE_INVERT_ARB', 0x80AB )
glget.addGLGetConstant( GL_SAMPLE_COVERAGE_INVERT_ARB, (1,) )
GL_MULTISAMPLE_BIT_ARB = constant.Constant( 'GL_MULTISAMPLE_BIT_ARB', 0x20000000 )
glSampleCoverageARB = platform.createExtensionFunction( 
'glSampleCoverageARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLclampf,constants.GLboolean,),
doc='glSampleCoverageARB(GLclampf(value), GLboolean(invert)) -> None',
argNames=('value','invert',),
deprecated=_DEPRECATED,
)


def glInitMultisampleARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.imaging_DEPRECATED

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_imaging'
_DEPRECATED = True
GL_CONVOLUTION_1D = constant.Constant( 'GL_CONVOLUTION_1D', 0x8010 )
GL_CONVOLUTION_2D = constant.Constant( 'GL_CONVOLUTION_2D', 0x8011 )
GL_SEPARABLE_2D = constant.Constant( 'GL_SEPARABLE_2D', 0x8012 )
GL_CONVOLUTION_BORDER_MODE = constant.Constant( 'GL_CONVOLUTION_BORDER_MODE', 0x8013 )
GL_CONVOLUTION_FILTER_SCALE = constant.Constant( 'GL_CONVOLUTION_FILTER_SCALE', 0x8014 )
GL_CONVOLUTION_FILTER_BIAS = constant.Constant( 'GL_CONVOLUTION_FILTER_BIAS', 0x8015 )
GL_REDUCE = constant.Constant( 'GL_REDUCE', 0x8016 )
GL_CONVOLUTION_FORMAT = constant.Constant( 'GL_CONVOLUTION_FORMAT', 0x8017 )
GL_CONVOLUTION_WIDTH = constant.Constant( 'GL_CONVOLUTION_WIDTH', 0x8018 )
GL_CONVOLUTION_HEIGHT = constant.Constant( 'GL_CONVOLUTION_HEIGHT', 0x8019 )
GL_MAX_CONVOLUTION_WIDTH = constant.Constant( 'GL_MAX_CONVOLUTION_WIDTH', 0x801A )
GL_MAX_CONVOLUTION_HEIGHT = constant.Constant( 'GL_MAX_CONVOLUTION_HEIGHT', 0x801B )
GL_POST_CONVOLUTION_RED_SCALE = constant.Constant( 'GL_POST_CONVOLUTION_RED_SCALE', 0x801C )
GL_POST_CONVOLUTION_GREEN_SCALE = constant.Constant( 'GL_POST_CONVOLUTION_GREEN_SCALE', 0x801D )
GL_POST_CONVOLUTION_BLUE_SCALE = constant.Constant( 'GL_POST_CONVOLUTION_BLUE_SCALE', 0x801E )
GL_POST_CONVOLUTION_ALPHA_SCALE = constant.Constant( 'GL_POST_CONVOLUTION_ALPHA_SCALE', 0x801F )
GL_POST_CONVOLUTION_RED_BIAS = constant.Constant( 'GL_POST_CONVOLUTION_RED_BIAS', 0x8020 )
GL_POST_CONVOLUTION_GREEN_BIAS = constant.Constant( 'GL_POST_CONVOLUTION_GREEN_BIAS', 0x8021 )
GL_POST_CONVOLUTION_BLUE_BIAS = constant.Constant( 'GL_POST_CONVOLUTION_BLUE_BIAS', 0x8022 )
GL_POST_CONVOLUTION_ALPHA_BIAS = constant.Constant( 'GL_POST_CONVOLUTION_ALPHA_BIAS', 0x8023 )
GL_HISTOGRAM = constant.Constant( 'GL_HISTOGRAM', 0x8024 )
GL_PROXY_HISTOGRAM = constant.Constant( 'GL_PROXY_HISTOGRAM', 0x8025 )
GL_HISTOGRAM_WIDTH = constant.Constant( 'GL_HISTOGRAM_WIDTH', 0x8026 )
GL_HISTOGRAM_FORMAT = constant.Constant( 'GL_HISTOGRAM_FORMAT', 0x8027 )
GL_HISTOGRAM_RED_SIZE = constant.Constant( 'GL_HISTOGRAM_RED_SIZE', 0x8028 )
GL_HISTOGRAM_GREEN_SIZE = constant.Constant( 'GL_HISTOGRAM_GREEN_SIZE', 0x8029 )
GL_HISTOGRAM_BLUE_SIZE = constant.Constant( 'GL_HISTOGRAM_BLUE_SIZE', 0x802A )
GL_HISTOGRAM_ALPHA_SIZE = constant.Constant( 'GL_HISTOGRAM_ALPHA_SIZE', 0x802B )
GL_HISTOGRAM_LUMINANCE_SIZE = constant.Constant( 'GL_HISTOGRAM_LUMINANCE_SIZE', 0x802C )
GL_HISTOGRAM_SINK = constant.Constant( 'GL_HISTOGRAM_SINK', 0x802D )
GL_MINMAX = constant.Constant( 'GL_MINMAX', 0x802E )
GL_MINMAX_FORMAT = constant.Constant( 'GL_MINMAX_FORMAT', 0x802F )
GL_MINMAX_SINK = constant.Constant( 'GL_MINMAX_SINK', 0x8030 )
GL_TABLE_TOO_LARGE = constant.Constant( 'GL_TABLE_TOO_LARGE', 0x8031 )
GL_COLOR_MATRIX = constant.Constant( 'GL_COLOR_MATRIX', 0x80B1 )
glget.addGLGetConstant( GL_COLOR_MATRIX, (4,4) )
GL_COLOR_MATRIX_STACK_DEPTH = constant.Constant( 'GL_COLOR_MATRIX_STACK_DEPTH', 0x80B2 )
GL_MAX_COLOR_MATRIX_STACK_DEPTH = constant.Constant( 'GL_MAX_COLOR_MATRIX_STACK_DEPTH', 0x80B3 )
GL_POST_COLOR_MATRIX_RED_SCALE = constant.Constant( 'GL_POST_COLOR_MATRIX_RED_SCALE', 0x80B4 )
GL_POST_COLOR_MATRIX_GREEN_SCALE = constant.Constant( 'GL_POST_COLOR_MATRIX_GREEN_SCALE', 0x80B5 )
GL_POST_COLOR_MATRIX_BLUE_SCALE = constant.Constant( 'GL_POST_COLOR_MATRIX_BLUE_SCALE', 0x80B6 )
GL_POST_COLOR_MATRIX_ALPHA_SCALE = constant.Constant( 'GL_POST_COLOR_MATRIX_ALPHA_SCALE', 0x80B7 )
GL_POST_COLOR_MATRIX_RED_BIAS = constant.Constant( 'GL_POST_COLOR_MATRIX_RED_BIAS', 0x80B8 )
GL_POST_COLOR_MATRIX_GREEN_BIAS = constant.Constant( 'GL_POST_COLOR_MATRIX_GREEN_BIAS', 0x80B9 )
GL_POST_COLOR_MATRIX_BLUE_BIAS = constant.Constant( 'GL_POST_COLOR_MATRIX_BLUE_BIAS', 0x80BA )
GL_POST_COLOR_MATRIX_ALPHA_BIAS = constant.Constant( 'GL_POST_COLOR_MATRIX_ALPHA_BIAS', 0x80BB )
GL_COLOR_TABLE = constant.Constant( 'GL_COLOR_TABLE', 0x80D0 )
GL_POST_CONVOLUTION_COLOR_TABLE = constant.Constant( 'GL_POST_CONVOLUTION_COLOR_TABLE', 0x80D1 )
GL_POST_COLOR_MATRIX_COLOR_TABLE = constant.Constant( 'GL_POST_COLOR_MATRIX_COLOR_TABLE', 0x80D2 )
GL_PROXY_COLOR_TABLE = constant.Constant( 'GL_PROXY_COLOR_TABLE', 0x80D3 )
GL_PROXY_POST_CONVOLUTION_COLOR_TABLE = constant.Constant( 'GL_PROXY_POST_CONVOLUTION_COLOR_TABLE', 0x80D4 )
GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE = constant.Constant( 'GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE', 0x80D5 )
GL_COLOR_TABLE_SCALE = constant.Constant( 'GL_COLOR_TABLE_SCALE', 0x80D6 )
GL_COLOR_TABLE_BIAS = constant.Constant( 'GL_COLOR_TABLE_BIAS', 0x80D7 )
GL_COLOR_TABLE_FORMAT = constant.Constant( 'GL_COLOR_TABLE_FORMAT', 0x80D8 )
GL_COLOR_TABLE_WIDTH = constant.Constant( 'GL_COLOR_TABLE_WIDTH', 0x80D9 )
GL_COLOR_TABLE_RED_SIZE = constant.Constant( 'GL_COLOR_TABLE_RED_SIZE', 0x80DA )
GL_COLOR_TABLE_GREEN_SIZE = constant.Constant( 'GL_COLOR_TABLE_GREEN_SIZE', 0x80DB )
GL_COLOR_TABLE_BLUE_SIZE = constant.Constant( 'GL_COLOR_TABLE_BLUE_SIZE', 0x80DC )
GL_COLOR_TABLE_ALPHA_SIZE = constant.Constant( 'GL_COLOR_TABLE_ALPHA_SIZE', 0x80DD )
GL_COLOR_TABLE_LUMINANCE_SIZE = constant.Constant( 'GL_COLOR_TABLE_LUMINANCE_SIZE', 0x80DE )
GL_COLOR_TABLE_INTENSITY_SIZE = constant.Constant( 'GL_COLOR_TABLE_INTENSITY_SIZE', 0x80DF )
GL_CONSTANT_BORDER = constant.Constant( 'GL_CONSTANT_BORDER', 0x8151 )
GL_REPLICATE_BORDER = constant.Constant( 'GL_REPLICATE_BORDER', 0x8153 )
GL_CONVOLUTION_BORDER_COLOR = constant.Constant( 'GL_CONVOLUTION_BORDER_COLOR', 0x8154 )


def glInitImagingDeprecatedARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.texture_env_combine4

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_texture_env_combine4'
_DEPRECATED = False
GL_COMBINE4_NV = constant.Constant( 'GL_COMBINE4_NV', 0x8503 )
GL_SOURCE3_RGB_NV = constant.Constant( 'GL_SOURCE3_RGB_NV', 0x8583 )
GL_SOURCE3_ALPHA_NV = constant.Constant( 'GL_SOURCE3_ALPHA_NV', 0x858B )
GL_OPERAND3_RGB_NV = constant.Constant( 'GL_OPERAND3_RGB_NV', 0x8593 )
GL_OPERAND3_ALPHA_NV = constant.Constant( 'GL_OPERAND3_ALPHA_NV', 0x859B )


def glInitTextureEnvCombine4NV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension VERSION.GL_1_3_DEPRECATED

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_1_3'
_DEPRECATED = True
GL_CLIENT_ACTIVE_TEXTURE = constant.Constant( 'GL_CLIENT_ACTIVE_TEXTURE', 0x84E1 )
GL_MAX_TEXTURE_UNITS = constant.Constant( 'GL_MAX_TEXTURE_UNITS', 0x84E2 )
GL_TRANSPOSE_MODELVIEW_MATRIX = constant.Constant( 'GL_TRANSPOSE_MODELVIEW_MATRIX', 0x84E3 )
GL_TRANSPOSE_PROJECTION_MATRIX = constant.Constant( 'GL_TRANSPOSE_PROJECTION_MATRIX', 0x84E4 )
GL_TRANSPOSE_TEXTURE_MATRIX = constant.Constant( 'GL_TRANSPOSE_TEXTURE_MATRIX', 0x84E5 )
GL_TRANSPOSE_COLOR_MATRIX = constant.Constant( 'GL_TRANSPOSE_COLOR_MATRIX', 0x84E6 )
GL_MULTISAMPLE_BIT = constant.Constant( 'GL_MULTISAMPLE_BIT', 0x20000000 )
GL_NORMAL_MAP = constant.Constant( 'GL_NORMAL_MAP', 0x8511 )
GL_REFLECTION_MAP = constant.Constant( 'GL_REFLECTION_MAP', 0x8512 )
GL_COMPRESSED_ALPHA = constant.Constant( 'GL_COMPRESSED_ALPHA', 0x84E9 )
GL_COMPRESSED_LUMINANCE = constant.Constant( 'GL_COMPRESSED_LUMINANCE', 0x84EA )
GL_COMPRESSED_LUMINANCE_ALPHA = constant.Constant( 'GL_COMPRESSED_LUMINANCE_ALPHA', 0x84EB )
GL_COMPRESSED_INTENSITY = constant.Constant( 'GL_COMPRESSED_INTENSITY', 0x84EC )
GL_COMBINE = constant.Constant( 'GL_COMBINE', 0x8570 )
GL_COMBINE_RGB = constant.Constant( 'GL_COMBINE_RGB', 0x8571 )
GL_COMBINE_ALPHA = constant.Constant( 'GL_COMBINE_ALPHA', 0x8572 )
GL_SOURCE0_RGB = constant.Constant( 'GL_SOURCE0_RGB', 0x8580 )
GL_SOURCE1_RGB = constant.Constant( 'GL_SOURCE1_RGB', 0x8581 )
GL_SOURCE2_RGB = constant.Constant( 'GL_SOURCE2_RGB', 0x8582 )
GL_SOURCE0_ALPHA = constant.Constant( 'GL_SOURCE0_ALPHA', 0x8588 )
GL_SOURCE1_ALPHA = constant.Constant( 'GL_SOURCE1_ALPHA', 0x8589 )
GL_SOURCE2_ALPHA = constant.Constant( 'GL_SOURCE2_ALPHA', 0x858A )
GL_OPERAND0_RGB = constant.Constant( 'GL_OPERAND0_RGB', 0x8590 )
GL_OPERAND1_RGB = constant.Constant( 'GL_OPERAND1_RGB', 0x8591 )
GL_OPERAND2_RGB = constant.Constant( 'GL_OPERAND2_RGB', 0x8592 )
GL_OPERAND0_ALPHA = constant.Constant( 'GL_OPERAND0_ALPHA', 0x8598 )
GL_OPERAND1_ALPHA = constant.Constant( 'GL_OPERAND1_ALPHA', 0x8599 )
GL_OPERAND2_ALPHA = constant.Constant( 'GL_OPERAND2_ALPHA', 0x859A )
GL_RGB_SCALE = constant.Constant( 'GL_RGB_SCALE', 0x8573 )
GL_ADD_SIGNED = constant.Constant( 'GL_ADD_SIGNED', 0x8574 )
GL_INTERPOLATE = constant.Constant( 'GL_INTERPOLATE', 0x8575 )
GL_SUBTRACT = constant.Constant( 'GL_SUBTRACT', 0x84E7 )
GL_CONSTANT = constant.Constant( 'GL_CONSTANT', 0x8576 )
GL_PRIMARY_COLOR = constant.Constant( 'GL_PRIMARY_COLOR', 0x8577 )
GL_PREVIOUS = constant.Constant( 'GL_PREVIOUS', 0x8578 )
GL_DOT3_RGB = constant.Constant( 'GL_DOT3_RGB', 0x86AE )
GL_DOT3_RGBA = constant.Constant( 'GL_DOT3_RGBA', 0x86AF )
glClientActiveTexture = platform.createExtensionFunction( 
'glClientActiveTexture',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glClientActiveTexture(GLenum(texture)) -> None',
argNames=('texture',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1d = platform.createExtensionFunction( 
'glMultiTexCoord1d',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,),
doc='glMultiTexCoord1d(GLenum(target), GLdouble(s)) -> None',
argNames=('target','s',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1dv = platform.createExtensionFunction( 
'glMultiTexCoord1dv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMultiTexCoord1dv(GLenum(target), GLdoubleArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1f = platform.createExtensionFunction( 
'glMultiTexCoord1f',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,),
doc='glMultiTexCoord1f(GLenum(target), GLfloat(s)) -> None',
argNames=('target','s',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1fv = platform.createExtensionFunction( 
'glMultiTexCoord1fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMultiTexCoord1fv(GLenum(target), GLfloatArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1i = platform.createExtensionFunction( 
'glMultiTexCoord1i',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,),
doc='glMultiTexCoord1i(GLenum(target), GLint(s)) -> None',
argNames=('target','s',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1iv = platform.createExtensionFunction( 
'glMultiTexCoord1iv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glMultiTexCoord1iv(GLenum(target), GLintArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1s = platform.createExtensionFunction( 
'glMultiTexCoord1s',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLshort,),
doc='glMultiTexCoord1s(GLenum(target), GLshort(s)) -> None',
argNames=('target','s',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1sv = platform.createExtensionFunction( 
'glMultiTexCoord1sv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLshortArray,),
doc='glMultiTexCoord1sv(GLenum(target), GLshortArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2d = platform.createExtensionFunction( 
'glMultiTexCoord2d',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,),
doc='glMultiTexCoord2d(GLenum(target), GLdouble(s), GLdouble(t)) -> None',
argNames=('target','s','t',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2dv = platform.createExtensionFunction( 
'glMultiTexCoord2dv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMultiTexCoord2dv(GLenum(target), GLdoubleArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2f = platform.createExtensionFunction( 
'glMultiTexCoord2f',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,),
doc='glMultiTexCoord2f(GLenum(target), GLfloat(s), GLfloat(t)) -> None',
argNames=('target','s','t',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2fv = platform.createExtensionFunction( 
'glMultiTexCoord2fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMultiTexCoord2fv(GLenum(target), GLfloatArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2i = platform.createExtensionFunction( 
'glMultiTexCoord2i',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,),
doc='glMultiTexCoord2i(GLenum(target), GLint(s), GLint(t)) -> None',
argNames=('target','s','t',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2iv = platform.createExtensionFunction( 
'glMultiTexCoord2iv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glMultiTexCoord2iv(GLenum(target), GLintArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2s = platform.createExtensionFunction( 
'glMultiTexCoord2s',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLshort,constants.GLshort,),
doc='glMultiTexCoord2s(GLenum(target), GLshort(s), GLshort(t)) -> None',
argNames=('target','s','t',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2sv = platform.createExtensionFunction( 
'glMultiTexCoord2sv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLshortArray,),
doc='glMultiTexCoord2sv(GLenum(target), GLshortArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3d = platform.createExtensionFunction( 
'glMultiTexCoord3d',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glMultiTexCoord3d(GLenum(target), GLdouble(s), GLdouble(t), GLdouble(r)) -> None',
argNames=('target','s','t','r',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3dv = platform.createExtensionFunction( 
'glMultiTexCoord3dv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMultiTexCoord3dv(GLenum(target), GLdoubleArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3f = platform.createExtensionFunction( 
'glMultiTexCoord3f',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glMultiTexCoord3f(GLenum(target), GLfloat(s), GLfloat(t), GLfloat(r)) -> None',
argNames=('target','s','t','r',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3fv = platform.createExtensionFunction( 
'glMultiTexCoord3fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMultiTexCoord3fv(GLenum(target), GLfloatArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3i = platform.createExtensionFunction( 
'glMultiTexCoord3i',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,),
doc='glMultiTexCoord3i(GLenum(target), GLint(s), GLint(t), GLint(r)) -> None',
argNames=('target','s','t','r',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3iv = platform.createExtensionFunction( 
'glMultiTexCoord3iv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glMultiTexCoord3iv(GLenum(target), GLintArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3s = platform.createExtensionFunction( 
'glMultiTexCoord3s',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glMultiTexCoord3s(GLenum(target), GLshort(s), GLshort(t), GLshort(r)) -> None',
argNames=('target','s','t','r',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3sv = platform.createExtensionFunction( 
'glMultiTexCoord3sv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLshortArray,),
doc='glMultiTexCoord3sv(GLenum(target), GLshortArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4d = platform.createExtensionFunction( 
'glMultiTexCoord4d',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glMultiTexCoord4d(GLenum(target), GLdouble(s), GLdouble(t), GLdouble(r), GLdouble(q)) -> None',
argNames=('target','s','t','r','q',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4dv = platform.createExtensionFunction( 
'glMultiTexCoord4dv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMultiTexCoord4dv(GLenum(target), GLdoubleArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4f = platform.createExtensionFunction( 
'glMultiTexCoord4f',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glMultiTexCoord4f(GLenum(target), GLfloat(s), GLfloat(t), GLfloat(r), GLfloat(q)) -> None',
argNames=('target','s','t','r','q',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4fv = platform.createExtensionFunction( 
'glMultiTexCoord4fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMultiTexCoord4fv(GLenum(target), GLfloatArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4i = platform.createExtensionFunction( 
'glMultiTexCoord4i',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glMultiTexCoord4i(GLenum(target), GLint(s), GLint(t), GLint(r), GLint(q)) -> None',
argNames=('target','s','t','r','q',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4iv = platform.createExtensionFunction( 
'glMultiTexCoord4iv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glMultiTexCoord4iv(GLenum(target), GLintArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4s = platform.createExtensionFunction( 
'glMultiTexCoord4s',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLshort,constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glMultiTexCoord4s(GLenum(target), GLshort(s), GLshort(t), GLshort(r), GLshort(q)) -> None',
argNames=('target','s','t','r','q',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4sv = platform.createExtensionFunction( 
'glMultiTexCoord4sv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLshortArray,),
doc='glMultiTexCoord4sv(GLenum(target), GLshortArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glLoadTransposeMatrixf = platform.createExtensionFunction( 
'glLoadTransposeMatrixf',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,),
doc='glLoadTransposeMatrixf(GLfloatArray(m)) -> None',
argNames=('m',),
deprecated=_DEPRECATED,
)

glLoadTransposeMatrixd = platform.createExtensionFunction( 
'glLoadTransposeMatrixd',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLdoubleArray,),
doc='glLoadTransposeMatrixd(GLdoubleArray(m)) -> None',
argNames=('m',),
deprecated=_DEPRECATED,
)

glMultTransposeMatrixf = platform.createExtensionFunction( 
'glMultTransposeMatrixf',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,),
doc='glMultTransposeMatrixf(GLfloatArray(m)) -> None',
argNames=('m',),
deprecated=_DEPRECATED,
)

glMultTransposeMatrixd = platform.createExtensionFunction( 
'glMultTransposeMatrixd',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLdoubleArray,),
doc='glMultTransposeMatrixd(GLdoubleArray(m)) -> None',
argNames=('m',),
deprecated=_DEPRECATED,
)




'''OpenGL extension EXT.light_texture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_light_texture'
_DEPRECATED = False
GL_FRAGMENT_MATERIAL_EXT = constant.Constant( 'GL_FRAGMENT_MATERIAL_EXT', 0x8349 )
GL_FRAGMENT_NORMAL_EXT = constant.Constant( 'GL_FRAGMENT_NORMAL_EXT', 0x834A )
GL_FRAGMENT_COLOR_EXT = constant.Constant( 'GL_FRAGMENT_COLOR_EXT', 0x834C )
GL_ATTENUATION_EXT = constant.Constant( 'GL_ATTENUATION_EXT', 0x834D )
GL_SHADOW_ATTENUATION_EXT = constant.Constant( 'GL_SHADOW_ATTENUATION_EXT', 0x834E )
GL_TEXTURE_APPLICATION_MODE_EXT = constant.Constant( 'GL_TEXTURE_APPLICATION_MODE_EXT', 0x834F )
GL_TEXTURE_LIGHT_EXT = constant.Constant( 'GL_TEXTURE_LIGHT_EXT', 0x8350 )
GL_TEXTURE_MATERIAL_FACE_EXT = constant.Constant( 'GL_TEXTURE_MATERIAL_FACE_EXT', 0x8351 )
GL_TEXTURE_MATERIAL_PARAMETER_EXT = constant.Constant( 'GL_TEXTURE_MATERIAL_PARAMETER_EXT', 0x8352 )
glApplyTextureEXT = platform.createExtensionFunction( 
'glApplyTextureEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glApplyTextureEXT(GLenum(mode)) -> None',
argNames=('mode',),
deprecated=_DEPRECATED,
)

glTextureLightEXT = platform.createExtensionFunction( 
'glTextureLightEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glTextureLightEXT(GLenum(pname)) -> None',
argNames=('pname',),
deprecated=_DEPRECATED,
)

glTextureMaterialEXT = platform.createExtensionFunction( 
'glTextureMaterialEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glTextureMaterialEXT(GLenum(face), GLenum(mode)) -> None',
argNames=('face','mode',),
deprecated=_DEPRECATED,
)


def glInitLightTextureEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.packed_float

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_packed_float'
_DEPRECATED = False
GL_R11F_G11F_B10F_EXT = constant.Constant( 'GL_R11F_G11F_B10F_EXT', 0x8C3A )
GL_UNSIGNED_INT_10F_11F_11F_REV_EXT = constant.Constant( 'GL_UNSIGNED_INT_10F_11F_11F_REV_EXT', 0x8C3B )
GL_RGBA_SIGNED_COMPONENTS_EXT = constant.Constant( 'GL_RGBA_SIGNED_COMPONENTS_EXT', 0x8C3C )


def glInitPackedFloatEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
